import { z } from 'zod';
export declare const GlobalConfigSchema: z.ZodObject<{
    meta: z.ZodObject<{
        displayName: z.ZodString;
        name: z.ZodString;
        restRoot: z.ZodString;
        apiVersion: z.ZodOptional<z.ZodString>;
        version: z.ZodString;
        schemaVersion: z.ZodOptional<z.ZodString>;
        _uccVersion: z.ZodOptional<z.ZodString>;
        hideUCCVersion: z.ZodOptional<z.ZodBoolean>;
        checkForUpdates: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
        searchViewDefault: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
        isVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
        supportedThemes: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    }, "strip", z.ZodTypeAny, {
        displayName: string;
        name: string;
        restRoot: string;
        version: string;
        apiVersion?: string | undefined;
        schemaVersion?: string | undefined;
        _uccVersion?: string | undefined;
        hideUCCVersion?: boolean | undefined;
        checkForUpdates?: boolean | undefined;
        searchViewDefault?: boolean | undefined;
        isVisible?: boolean | undefined;
        supportedThemes?: string[] | undefined;
    }, {
        displayName: string;
        name: string;
        restRoot: string;
        version: string;
        apiVersion?: string | undefined;
        schemaVersion?: string | undefined;
        _uccVersion?: string | undefined;
        hideUCCVersion?: boolean | undefined;
        checkForUpdates?: boolean | undefined;
        searchViewDefault?: boolean | undefined;
        isVisible?: boolean | undefined;
        supportedThemes?: string[] | undefined;
    }>;
    pages: z.ZodObject<{
        configuration: z.ZodObject<{
            title: z.ZodString;
            description: z.ZodOptional<z.ZodString>;
            subDescription: z.ZodOptional<z.ZodObject<{
                text: z.ZodString;
                links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    slug: z.ZodString;
                    link: z.ZodString;
                    linkText: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    linkText: string;
                    link: string;
                    slug: string;
                }, {
                    linkText: string;
                    link: string;
                    slug: string;
                }>, "many">>;
            }, "strip", z.ZodTypeAny, {
                text: string;
                links?: {
                    linkText: string;
                    link: string;
                    slug: string;
                }[] | undefined;
            }, {
                text: string;
                links?: {
                    linkText: string;
                    link: string;
                    slug: string;
                }[] | undefined;
            }>>;
            tabs: z.ZodArray<z.ZodObject<{
                entity: z.ZodOptional<z.ZodArray<z.ZodDiscriminatedUnion<"type", [z.ZodObject<z.objectUtil.extendShape<{
                    type: z.ZodString;
                    field: z.ZodString;
                    label: z.ZodString;
                    help: z.ZodOptional<z.ZodString>;
                    tooltip: z.ZodOptional<z.ZodString>;
                }, {
                    type: z.ZodLiteral<"helpLink">;
                    label: z.ZodOptional<z.ZodString>;
                    options: z.ZodObject<{
                        text: z.ZodString;
                        link: z.ZodString;
                        hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                    }, "strip", z.ZodTypeAny, {
                        text: string;
                        link: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    }, {
                        text: string;
                        link: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    }>;
                    required: z.ZodOptional<z.ZodDefault<z.ZodLiteral<false>>>;
                }>, "strip", z.ZodTypeAny, {
                    options: {
                        text: string;
                        link: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "helpLink";
                    field: string;
                    label?: string | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: false | undefined;
                }, {
                    options: {
                        text: string;
                        link: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "helpLink";
                    field: string;
                    label?: string | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: false | undefined;
                }>, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                    type: z.ZodString;
                    field: z.ZodString;
                    label: z.ZodString;
                    help: z.ZodOptional<z.ZodString>;
                    tooltip: z.ZodOptional<z.ZodString>;
                }, {
                    required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }>, {
                    type: z.ZodLiteral<"text">;
                    validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"number">;
                        range: z.ZodArray<z.ZodNumber, "many">;
                        isInteger: z.ZodOptional<z.ZodBoolean>;
                    }, "strip", z.ZodTypeAny, {
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    }, {
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"string">;
                        minLength: z.ZodNumber;
                        maxLength: z.ZodNumber;
                    }, "strip", z.ZodTypeAny, {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    }, {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"regex">;
                        pattern: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"email">;
                    }, "strip", z.ZodTypeAny, {
                        type: "email";
                        errorMsg?: string | undefined;
                    }, {
                        type: "email";
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"ipv4">;
                    }, "strip", z.ZodTypeAny, {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    }, {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"url">;
                    }, "strip", z.ZodTypeAny, {
                        type: "url";
                        errorMsg?: string | undefined;
                    }, {
                        type: "url";
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"date">;
                    }, "strip", z.ZodTypeAny, {
                        type: "date";
                        errorMsg?: string | undefined;
                    }, {
                        type: "date";
                        errorMsg?: string | undefined;
                    }>]>, "many">>;
                    defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
                    options: z.ZodOptional<z.ZodObject<{
                        display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                    }, "strip", z.ZodTypeAny, {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    }, {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    }>>;
                    modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                        mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                        fieldsToModify: z.ZodArray<z.ZodObject<{
                            fieldId: z.ZodString;
                            display: z.ZodOptional<z.ZodBoolean>;
                            value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                            disabled: z.ZodOptional<z.ZodBoolean>;
                            required: z.ZodOptional<z.ZodBoolean>;
                            help: z.ZodOptional<z.ZodString>;
                            label: z.ZodOptional<z.ZodString>;
                            markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                                markdownType: z.ZodLiteral<"text">;
                                text: z.ZodString;
                                color: z.ZodOptional<z.ZodString>;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"hybrid">;
                                text: z.ZodString;
                                token: z.ZodString;
                                linkText: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"link">;
                                text: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodOptional<z.ZodUndefined>;
                                text: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                text: string;
                                markdownType?: undefined;
                            }, {
                                text: string;
                                markdownType?: undefined;
                            }>]>>;
                        }, "strip", z.ZodTypeAny, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }>, "many">;
                    }, "strip", z.ZodTypeAny, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }>, "many">>;
                }>, "strip", z.ZodTypeAny, {
                    type: "text";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }, {
                    type: "text";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }>, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                    type: z.ZodString;
                    field: z.ZodString;
                    label: z.ZodString;
                    help: z.ZodOptional<z.ZodString>;
                    tooltip: z.ZodOptional<z.ZodString>;
                }, {
                    required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }>, {
                    type: z.ZodLiteral<"textarea">;
                    validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"number">;
                        range: z.ZodArray<z.ZodNumber, "many">;
                        isInteger: z.ZodOptional<z.ZodBoolean>;
                    }, "strip", z.ZodTypeAny, {
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    }, {
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"string">;
                        minLength: z.ZodNumber;
                        maxLength: z.ZodNumber;
                    }, "strip", z.ZodTypeAny, {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    }, {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"regex">;
                        pattern: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"email">;
                    }, "strip", z.ZodTypeAny, {
                        type: "email";
                        errorMsg?: string | undefined;
                    }, {
                        type: "email";
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"ipv4">;
                    }, "strip", z.ZodTypeAny, {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    }, {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"url">;
                    }, "strip", z.ZodTypeAny, {
                        type: "url";
                        errorMsg?: string | undefined;
                    }, {
                        type: "url";
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"date">;
                    }, "strip", z.ZodTypeAny, {
                        type: "date";
                        errorMsg?: string | undefined;
                    }, {
                        type: "date";
                        errorMsg?: string | undefined;
                    }>]>, "many">>;
                    defaultValue: z.ZodOptional<z.ZodString>;
                    options: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
                        display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                    }, {
                        rowsMin: z.ZodOptional<z.ZodNumber>;
                        rowsMax: z.ZodOptional<z.ZodNumber>;
                    }>, "strip", z.ZodTypeAny, {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    }, {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    }>>;
                    modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                        mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                        fieldsToModify: z.ZodArray<z.ZodObject<{
                            fieldId: z.ZodString;
                            display: z.ZodOptional<z.ZodBoolean>;
                            value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                            disabled: z.ZodOptional<z.ZodBoolean>;
                            required: z.ZodOptional<z.ZodBoolean>;
                            help: z.ZodOptional<z.ZodString>;
                            label: z.ZodOptional<z.ZodString>;
                            markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                                markdownType: z.ZodLiteral<"text">;
                                text: z.ZodString;
                                color: z.ZodOptional<z.ZodString>;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"hybrid">;
                                text: z.ZodString;
                                token: z.ZodString;
                                linkText: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"link">;
                                text: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodOptional<z.ZodUndefined>;
                                text: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                text: string;
                                markdownType?: undefined;
                            }, {
                                text: string;
                                markdownType?: undefined;
                            }>]>>;
                        }, "strip", z.ZodTypeAny, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }>, "many">;
                    }, "strip", z.ZodTypeAny, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }>, "many">>;
                }>, "strip", z.ZodTypeAny, {
                    type: "textarea";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }, {
                    type: "textarea";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }>, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                    type: z.ZodString;
                    field: z.ZodString;
                    label: z.ZodString;
                    help: z.ZodOptional<z.ZodString>;
                    tooltip: z.ZodOptional<z.ZodString>;
                }, {
                    required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }>, {
                    type: z.ZodLiteral<"singleSelect">;
                    validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"number">;
                        range: z.ZodArray<z.ZodNumber, "many">;
                        isInteger: z.ZodOptional<z.ZodBoolean>;
                    }, "strip", z.ZodTypeAny, {
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    }, {
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"string">;
                        minLength: z.ZodNumber;
                        maxLength: z.ZodNumber;
                    }, "strip", z.ZodTypeAny, {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    }, {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"regex">;
                        pattern: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"email">;
                    }, "strip", z.ZodTypeAny, {
                        type: "email";
                        errorMsg?: string | undefined;
                    }, {
                        type: "email";
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"ipv4">;
                    }, "strip", z.ZodTypeAny, {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    }, {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"url">;
                    }, "strip", z.ZodTypeAny, {
                        type: "url";
                        errorMsg?: string | undefined;
                    }, {
                        type: "url";
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"date">;
                    }, "strip", z.ZodTypeAny, {
                        type: "date";
                        errorMsg?: string | undefined;
                    }, {
                        type: "date";
                        errorMsg?: string | undefined;
                    }>]>, "many">>;
                    defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
                    options: z.ZodObject<z.objectUtil.extendShape<{
                        display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                    }, {
                        disableSearch: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        createSearchChoice: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        referenceName: z.ZodOptional<z.ZodString>;
                        endpointUrl: z.ZodOptional<z.ZodString>;
                        allowList: z.ZodOptional<z.ZodString>;
                        denyList: z.ZodOptional<z.ZodString>;
                        labelField: z.ZodOptional<z.ZodString>;
                        valueField: z.ZodOptional<z.ZodString>;
                        autoCompleteFields: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                            value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                            label: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            value: string | number | boolean;
                            label: string;
                        }, {
                            value: string | number | boolean;
                            label: string;
                        }>, z.ZodObject<{
                            label: z.ZodString;
                            children: z.ZodArray<z.ZodObject<{
                                value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                                label: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                value: string | number | boolean;
                                label: string;
                            }, {
                                value: string | number | boolean;
                                label: string;
                            }>, "many">;
                        }, "strip", z.ZodTypeAny, {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        }, {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        }>]>, "many">>;
                        dependencies: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                        items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                            label: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            value: string | number | boolean;
                            label: string;
                        }, {
                            value: string | number | boolean;
                            label: string;
                        }>, "many">>;
                    }>, "strip", z.ZodTypeAny, {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    }, {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    }>;
                    modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                        mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                        fieldsToModify: z.ZodArray<z.ZodObject<{
                            fieldId: z.ZodString;
                            display: z.ZodOptional<z.ZodBoolean>;
                            value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                            disabled: z.ZodOptional<z.ZodBoolean>;
                            required: z.ZodOptional<z.ZodBoolean>;
                            help: z.ZodOptional<z.ZodString>;
                            label: z.ZodOptional<z.ZodString>;
                            markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                                markdownType: z.ZodLiteral<"text">;
                                text: z.ZodString;
                                color: z.ZodOptional<z.ZodString>;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"hybrid">;
                                text: z.ZodString;
                                token: z.ZodString;
                                linkText: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"link">;
                                text: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodOptional<z.ZodUndefined>;
                                text: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                text: string;
                                markdownType?: undefined;
                            }, {
                                text: string;
                                markdownType?: undefined;
                            }>]>>;
                        }, "strip", z.ZodTypeAny, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }>, "many">;
                    }, "strip", z.ZodTypeAny, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }>, "many">>;
                }>, "strip", z.ZodTypeAny, {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    };
                    type: "singleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }, {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    };
                    type: "singleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }>, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                    type: z.ZodString;
                    field: z.ZodString;
                    label: z.ZodString;
                    help: z.ZodOptional<z.ZodString>;
                    tooltip: z.ZodOptional<z.ZodString>;
                }, {
                    required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }>, {
                    type: z.ZodLiteral<"multipleSelect">;
                    validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"number">;
                        range: z.ZodArray<z.ZodNumber, "many">;
                        isInteger: z.ZodOptional<z.ZodBoolean>;
                    }, "strip", z.ZodTypeAny, {
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    }, {
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"string">;
                        minLength: z.ZodNumber;
                        maxLength: z.ZodNumber;
                    }, "strip", z.ZodTypeAny, {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    }, {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"regex">;
                        pattern: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"email">;
                    }, "strip", z.ZodTypeAny, {
                        type: "email";
                        errorMsg?: string | undefined;
                    }, {
                        type: "email";
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"ipv4">;
                    }, "strip", z.ZodTypeAny, {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    }, {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"url">;
                    }, "strip", z.ZodTypeAny, {
                        type: "url";
                        errorMsg?: string | undefined;
                    }, {
                        type: "url";
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"date">;
                    }, "strip", z.ZodTypeAny, {
                        type: "date";
                        errorMsg?: string | undefined;
                    }, {
                        type: "date";
                        errorMsg?: string | undefined;
                    }>]>, "many">>;
                    defaultValue: z.ZodOptional<z.ZodString>;
                    options: z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                        display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                    }, {
                        disableSearch: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        createSearchChoice: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        referenceName: z.ZodOptional<z.ZodString>;
                        endpointUrl: z.ZodOptional<z.ZodString>;
                        allowList: z.ZodOptional<z.ZodString>;
                        denyList: z.ZodOptional<z.ZodString>;
                        labelField: z.ZodOptional<z.ZodString>;
                        valueField: z.ZodOptional<z.ZodString>;
                        autoCompleteFields: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                            value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                            label: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            value: string | number | boolean;
                            label: string;
                        }, {
                            value: string | number | boolean;
                            label: string;
                        }>, z.ZodObject<{
                            label: z.ZodString;
                            children: z.ZodArray<z.ZodObject<{
                                value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                                label: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                value: string | number | boolean;
                                label: string;
                            }, {
                                value: string | number | boolean;
                                label: string;
                            }>, "many">;
                        }, "strip", z.ZodTypeAny, {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        }, {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        }>]>, "many">>;
                        dependencies: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                        items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                            label: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            value: string | number | boolean;
                            label: string;
                        }, {
                            value: string | number | boolean;
                            label: string;
                        }>, "many">>;
                    }>, {
                        delimiter: z.ZodOptional<z.ZodString>;
                    }>, "strip", z.ZodTypeAny, {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    }, {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    }>;
                    modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                        mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                        fieldsToModify: z.ZodArray<z.ZodObject<{
                            fieldId: z.ZodString;
                            display: z.ZodOptional<z.ZodBoolean>;
                            value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                            disabled: z.ZodOptional<z.ZodBoolean>;
                            required: z.ZodOptional<z.ZodBoolean>;
                            help: z.ZodOptional<z.ZodString>;
                            label: z.ZodOptional<z.ZodString>;
                            markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                                markdownType: z.ZodLiteral<"text">;
                                text: z.ZodString;
                                color: z.ZodOptional<z.ZodString>;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"hybrid">;
                                text: z.ZodString;
                                token: z.ZodString;
                                linkText: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"link">;
                                text: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodOptional<z.ZodUndefined>;
                                text: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                text: string;
                                markdownType?: undefined;
                            }, {
                                text: string;
                                markdownType?: undefined;
                            }>]>>;
                        }, "strip", z.ZodTypeAny, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }>, "many">;
                    }, "strip", z.ZodTypeAny, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }>, "many">>;
                }>, "strip", z.ZodTypeAny, {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    };
                    type: "multipleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }, {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    };
                    type: "multipleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }>, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                    type: z.ZodString;
                    field: z.ZodString;
                    label: z.ZodString;
                    help: z.ZodOptional<z.ZodString>;
                    tooltip: z.ZodOptional<z.ZodString>;
                }, {
                    required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }>, {
                    type: z.ZodLiteral<"checkbox">;
                    defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodBoolean]>>;
                    options: z.ZodOptional<z.ZodObject<{
                        display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                    }, "strip", z.ZodTypeAny, {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    }, {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    }>>;
                    modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                        mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                        fieldsToModify: z.ZodArray<z.ZodObject<{
                            fieldId: z.ZodString;
                            display: z.ZodOptional<z.ZodBoolean>;
                            value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                            disabled: z.ZodOptional<z.ZodBoolean>;
                            required: z.ZodOptional<z.ZodBoolean>;
                            help: z.ZodOptional<z.ZodString>;
                            label: z.ZodOptional<z.ZodString>;
                            markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                                markdownType: z.ZodLiteral<"text">;
                                text: z.ZodString;
                                color: z.ZodOptional<z.ZodString>;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"hybrid">;
                                text: z.ZodString;
                                token: z.ZodString;
                                linkText: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"link">;
                                text: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodOptional<z.ZodUndefined>;
                                text: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                text: string;
                                markdownType?: undefined;
                            }, {
                                text: string;
                                markdownType?: undefined;
                            }>]>>;
                        }, "strip", z.ZodTypeAny, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }>, "many">;
                    }, "strip", z.ZodTypeAny, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }>, "many">>;
                }>, "strip", z.ZodTypeAny, {
                    type: "checkbox";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }, {
                    type: "checkbox";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }>, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                    type: z.ZodString;
                    field: z.ZodString;
                    label: z.ZodString;
                    help: z.ZodOptional<z.ZodString>;
                    tooltip: z.ZodOptional<z.ZodString>;
                }, {
                    required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }>, {
                    type: z.ZodLiteral<"checkboxGroup">;
                    validators: z.ZodOptional<z.ZodTuple<[z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"regex">;
                        pattern: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }>], null>>;
                    defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodBoolean]>>;
                    options: z.ZodObject<z.objectUtil.extendShape<{
                        display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                    }, {
                        groups: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            label: z.ZodString;
                            fields: z.ZodArray<z.ZodString, "many">;
                            options: z.ZodOptional<z.ZodObject<{
                                isExpandable: z.ZodOptional<z.ZodBoolean>;
                                expand: z.ZodOptional<z.ZodBoolean>;
                            }, "strip", z.ZodTypeAny, {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            }, {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            }>>;
                        }, "strip", z.ZodTypeAny, {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }, {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }>, "many">>;
                        rows: z.ZodArray<z.ZodObject<{
                            field: z.ZodString;
                            checkbox: z.ZodOptional<z.ZodObject<{
                                label: z.ZodOptional<z.ZodString>;
                                defaultValue: z.ZodOptional<z.ZodBoolean>;
                            }, "strip", z.ZodTypeAny, {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            }, {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            }>>;
                            input: z.ZodOptional<z.ZodObject<{
                                defaultValue: z.ZodOptional<z.ZodNumber>;
                                validators: z.ZodOptional<z.ZodTuple<[z.ZodObject<{
                                    errorMsg: z.ZodOptional<z.ZodString>;
                                    type: z.ZodLiteral<"number">;
                                    range: z.ZodArray<z.ZodNumber, "many">;
                                    isInteger: z.ZodOptional<z.ZodBoolean>;
                                }, "strip", z.ZodTypeAny, {
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }, {
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }>], null>>;
                                required: z.ZodOptional<z.ZodBoolean>;
                            }, "strip", z.ZodTypeAny, {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            }, {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            }>>;
                        }, "strip", z.ZodTypeAny, {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }, {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }>, "many">;
                    }>, "strip", z.ZodTypeAny, {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    }, {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    }>;
                }>, "strip", z.ZodTypeAny, {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxGroup";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                }, {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxGroup";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                }>, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                    type: z.ZodString;
                    field: z.ZodString;
                    label: z.ZodString;
                    help: z.ZodOptional<z.ZodString>;
                    tooltip: z.ZodOptional<z.ZodString>;
                }, {
                    required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }>, {
                    type: z.ZodLiteral<"checkboxTree">;
                    validators: z.ZodOptional<z.ZodTuple<[z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"regex">;
                        pattern: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }>], null>>;
                    defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodBoolean]>>;
                    options: z.ZodObject<z.objectUtil.extendShape<{
                        display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                    }, {
                        groups: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            label: z.ZodString;
                            fields: z.ZodArray<z.ZodString, "many">;
                            options: z.ZodOptional<z.ZodObject<{
                                isExpandable: z.ZodOptional<z.ZodBoolean>;
                                expand: z.ZodOptional<z.ZodBoolean>;
                            }, "strip", z.ZodTypeAny, {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            }, {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            }>>;
                        }, "strip", z.ZodTypeAny, {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }, {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }>, "many">>;
                        rows: z.ZodArray<z.ZodObject<{
                            field: z.ZodString;
                            checkbox: z.ZodOptional<z.ZodObject<{
                                label: z.ZodOptional<z.ZodString>;
                                defaultValue: z.ZodOptional<z.ZodBoolean>;
                            }, "strip", z.ZodTypeAny, {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            }, {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            }>>;
                        }, "strip", z.ZodTypeAny, {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }, {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }>, "many">;
                    }>, "strip", z.ZodTypeAny, {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    }, {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    }>;
                }>, "strip", z.ZodTypeAny, {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxTree";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                }, {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxTree";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                }>, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                    type: z.ZodString;
                    field: z.ZodString;
                    label: z.ZodString;
                    help: z.ZodOptional<z.ZodString>;
                    tooltip: z.ZodOptional<z.ZodString>;
                }, {
                    required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }>, {
                    type: z.ZodLiteral<"radio">;
                    defaultValue: z.ZodOptional<z.ZodString>;
                    options: z.ZodObject<z.objectUtil.extendShape<{
                        display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                    }, {
                        items: z.ZodArray<z.ZodObject<{
                            value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                            label: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            value: string | number | boolean;
                            label: string;
                        }, {
                            value: string | number | boolean;
                            label: string;
                        }>, "many">;
                    }>, "strip", z.ZodTypeAny, {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    }, {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    }>;
                    modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                        mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                        fieldsToModify: z.ZodArray<z.ZodObject<{
                            fieldId: z.ZodString;
                            display: z.ZodOptional<z.ZodBoolean>;
                            value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                            disabled: z.ZodOptional<z.ZodBoolean>;
                            required: z.ZodOptional<z.ZodBoolean>;
                            help: z.ZodOptional<z.ZodString>;
                            label: z.ZodOptional<z.ZodString>;
                            markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                                markdownType: z.ZodLiteral<"text">;
                                text: z.ZodString;
                                color: z.ZodOptional<z.ZodString>;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"hybrid">;
                                text: z.ZodString;
                                token: z.ZodString;
                                linkText: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"link">;
                                text: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodOptional<z.ZodUndefined>;
                                text: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                text: string;
                                markdownType?: undefined;
                            }, {
                                text: string;
                                markdownType?: undefined;
                            }>]>>;
                        }, "strip", z.ZodTypeAny, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }>, "many">;
                    }, "strip", z.ZodTypeAny, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }>, "many">>;
                }>, "strip", z.ZodTypeAny, {
                    options: {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "radio";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }, {
                    options: {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "radio";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }>, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                    type: z.ZodString;
                    field: z.ZodString;
                    label: z.ZodString;
                    help: z.ZodOptional<z.ZodString>;
                    tooltip: z.ZodOptional<z.ZodString>;
                }, {
                    required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }>, {
                    type: z.ZodLiteral<"file">;
                    defaultValue: z.ZodOptional<z.ZodString>;
                    validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"string">;
                        minLength: z.ZodNumber;
                        maxLength: z.ZodNumber;
                    }, "strip", z.ZodTypeAny, {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    }, {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"regex">;
                        pattern: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }>]>, "many">>;
                    options: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
                        display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                    }, {
                        maxFileSize: z.ZodOptional<z.ZodNumber>;
                        fileSupportMessage: z.ZodOptional<z.ZodString>;
                        supportedFileTypes: z.ZodArray<z.ZodString, "many">;
                        useBase64Encoding: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    }>, "strip", z.ZodTypeAny, {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    }, {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    }>>;
                    modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                        mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                        fieldsToModify: z.ZodArray<z.ZodObject<{
                            fieldId: z.ZodString;
                            display: z.ZodOptional<z.ZodBoolean>;
                            value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                            disabled: z.ZodOptional<z.ZodBoolean>;
                            required: z.ZodOptional<z.ZodBoolean>;
                            help: z.ZodOptional<z.ZodString>;
                            label: z.ZodOptional<z.ZodString>;
                            markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                                markdownType: z.ZodLiteral<"text">;
                                text: z.ZodString;
                                color: z.ZodOptional<z.ZodString>;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"hybrid">;
                                text: z.ZodString;
                                token: z.ZodString;
                                linkText: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"link">;
                                text: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodOptional<z.ZodUndefined>;
                                text: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                text: string;
                                markdownType?: undefined;
                            }, {
                                text: string;
                                markdownType?: undefined;
                            }>]>>;
                        }, "strip", z.ZodTypeAny, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }>, "many">;
                    }, "strip", z.ZodTypeAny, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }>, "many">>;
                }>, "strip", z.ZodTypeAny, {
                    type: "file";
                    label: string;
                    field: string;
                    options?: {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }, {
                    type: "file";
                    label: string;
                    field: string;
                    options?: {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }>, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                    type: z.ZodString;
                    field: z.ZodString;
                    label: z.ZodString;
                    help: z.ZodOptional<z.ZodString>;
                    tooltip: z.ZodOptional<z.ZodString>;
                }, {
                    required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }>, {
                    type: z.ZodLiteral<"oauth">;
                    defaultValue: z.ZodOptional<z.ZodString>;
                    validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"string">;
                        minLength: z.ZodNumber;
                        maxLength: z.ZodNumber;
                    }, "strip", z.ZodTypeAny, {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    }, {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"regex">;
                        pattern: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }>]>, "many">>;
                    options: z.ZodObject<z.objectUtil.extendShape<Omit<{
                        display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                    }, "requiredWhenVisible">, {
                        auth_type: z.ZodArray<z.ZodUnion<[z.ZodLiteral<"basic">, z.ZodLiteral<"oauth">]>, "many">;
                        basic: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            oauth_field: z.ZodString;
                            label: z.ZodString;
                            field: z.ZodString;
                            type: z.ZodOptional<z.ZodDefault<z.ZodLiteral<"text">>>;
                            help: z.ZodString;
                            encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
                            options: z.ZodOptional<z.ZodObject<{
                                display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                                disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                                enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                                requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                                hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                            }, "strip", z.ZodTypeAny, {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            }, {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            }>>;
                            modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                                mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                                fieldsToModify: z.ZodArray<z.ZodObject<{
                                    fieldId: z.ZodString;
                                    display: z.ZodOptional<z.ZodBoolean>;
                                    value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                                    disabled: z.ZodOptional<z.ZodBoolean>;
                                    required: z.ZodOptional<z.ZodBoolean>;
                                    help: z.ZodOptional<z.ZodString>;
                                    label: z.ZodOptional<z.ZodString>;
                                    markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                                        markdownType: z.ZodLiteral<"text">;
                                        text: z.ZodString;
                                        color: z.ZodOptional<z.ZodString>;
                                    }, "strip", z.ZodTypeAny, {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    }, {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    }>, z.ZodObject<{
                                        markdownType: z.ZodLiteral<"hybrid">;
                                        text: z.ZodString;
                                        token: z.ZodString;
                                        linkText: z.ZodString;
                                        link: z.ZodString;
                                    }, "strip", z.ZodTypeAny, {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    }, {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    }>, z.ZodObject<{
                                        markdownType: z.ZodLiteral<"link">;
                                        text: z.ZodString;
                                        link: z.ZodString;
                                    }, "strip", z.ZodTypeAny, {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    }, {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    }>, z.ZodObject<{
                                        markdownType: z.ZodOptional<z.ZodUndefined>;
                                        text: z.ZodString;
                                    }, "strip", z.ZodTypeAny, {
                                        text: string;
                                        markdownType?: undefined;
                                    }, {
                                        text: string;
                                        markdownType?: undefined;
                                    }>]>>;
                                }, "strip", z.ZodTypeAny, {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }, {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }>, "many">;
                            }, "strip", z.ZodTypeAny, {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }, {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }>, "many">>;
                            validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"number">;
                                range: z.ZodArray<z.ZodNumber, "many">;
                                isInteger: z.ZodOptional<z.ZodBoolean>;
                            }, "strip", z.ZodTypeAny, {
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }, {
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }>, z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"string">;
                                minLength: z.ZodNumber;
                                maxLength: z.ZodNumber;
                            }, "strip", z.ZodTypeAny, {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            }, {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            }>, z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"regex">;
                                pattern: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            }, {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            }>, z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"email">;
                            }, "strip", z.ZodTypeAny, {
                                type: "email";
                                errorMsg?: string | undefined;
                            }, {
                                type: "email";
                                errorMsg?: string | undefined;
                            }>, z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"ipv4">;
                            }, "strip", z.ZodTypeAny, {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            }, {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            }>, z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"url">;
                            }, "strip", z.ZodTypeAny, {
                                type: "url";
                                errorMsg?: string | undefined;
                            }, {
                                type: "url";
                                errorMsg?: string | undefined;
                            }>, z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"date">;
                            }, "strip", z.ZodTypeAny, {
                                type: "date";
                                errorMsg?: string | undefined;
                            }, {
                                type: "date";
                                errorMsg?: string | undefined;
                            }>]>, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }, {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }>, "many">>;
                        oauth: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            oauth_field: z.ZodString;
                            label: z.ZodString;
                            field: z.ZodString;
                            type: z.ZodOptional<z.ZodDefault<z.ZodLiteral<"text">>>;
                            help: z.ZodString;
                            encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
                            options: z.ZodOptional<z.ZodObject<{
                                display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                                disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                                enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                                requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                                hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                            }, "strip", z.ZodTypeAny, {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            }, {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            }>>;
                            modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                                mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                                fieldsToModify: z.ZodArray<z.ZodObject<{
                                    fieldId: z.ZodString;
                                    display: z.ZodOptional<z.ZodBoolean>;
                                    value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                                    disabled: z.ZodOptional<z.ZodBoolean>;
                                    required: z.ZodOptional<z.ZodBoolean>;
                                    help: z.ZodOptional<z.ZodString>;
                                    label: z.ZodOptional<z.ZodString>;
                                    markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                                        markdownType: z.ZodLiteral<"text">;
                                        text: z.ZodString;
                                        color: z.ZodOptional<z.ZodString>;
                                    }, "strip", z.ZodTypeAny, {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    }, {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    }>, z.ZodObject<{
                                        markdownType: z.ZodLiteral<"hybrid">;
                                        text: z.ZodString;
                                        token: z.ZodString;
                                        linkText: z.ZodString;
                                        link: z.ZodString;
                                    }, "strip", z.ZodTypeAny, {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    }, {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    }>, z.ZodObject<{
                                        markdownType: z.ZodLiteral<"link">;
                                        text: z.ZodString;
                                        link: z.ZodString;
                                    }, "strip", z.ZodTypeAny, {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    }, {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    }>, z.ZodObject<{
                                        markdownType: z.ZodOptional<z.ZodUndefined>;
                                        text: z.ZodString;
                                    }, "strip", z.ZodTypeAny, {
                                        text: string;
                                        markdownType?: undefined;
                                    }, {
                                        text: string;
                                        markdownType?: undefined;
                                    }>]>>;
                                }, "strip", z.ZodTypeAny, {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }, {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }>, "many">;
                            }, "strip", z.ZodTypeAny, {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }, {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }>, "many">>;
                            validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"number">;
                                range: z.ZodArray<z.ZodNumber, "many">;
                                isInteger: z.ZodOptional<z.ZodBoolean>;
                            }, "strip", z.ZodTypeAny, {
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }, {
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }>, z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"string">;
                                minLength: z.ZodNumber;
                                maxLength: z.ZodNumber;
                            }, "strip", z.ZodTypeAny, {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            }, {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            }>, z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"regex">;
                                pattern: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            }, {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            }>, z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"email">;
                            }, "strip", z.ZodTypeAny, {
                                type: "email";
                                errorMsg?: string | undefined;
                            }, {
                                type: "email";
                                errorMsg?: string | undefined;
                            }>, z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"ipv4">;
                            }, "strip", z.ZodTypeAny, {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            }, {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            }>, z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"url">;
                            }, "strip", z.ZodTypeAny, {
                                type: "url";
                                errorMsg?: string | undefined;
                            }, {
                                type: "url";
                                errorMsg?: string | undefined;
                            }>, z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"date">;
                            }, "strip", z.ZodTypeAny, {
                                type: "date";
                                errorMsg?: string | undefined;
                            }, {
                                type: "date";
                                errorMsg?: string | undefined;
                            }>]>, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }, {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }>, "many">>;
                        auth_label: z.ZodOptional<z.ZodString>;
                        oauth_popup_width: z.ZodOptional<z.ZodNumber>;
                        oauth_popup_height: z.ZodOptional<z.ZodNumber>;
                        oauth_timeout: z.ZodOptional<z.ZodNumber>;
                        auth_code_endpoint: z.ZodOptional<z.ZodString>;
                        access_token_endpoint: z.ZodOptional<z.ZodString>;
                        oauth_state_enabled: z.ZodOptional<z.ZodBoolean>;
                        auth_endpoint_token_access_type: z.ZodOptional<z.ZodString>;
                    }>, "strip", z.ZodTypeAny, {
                        auth_type: ("oauth" | "basic")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    }, {
                        auth_type: ("oauth" | "basic")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    }>;
                }>, "strip", z.ZodTypeAny, {
                    options: {
                        auth_type: ("oauth" | "basic")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    };
                    type: "oauth";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                }, {
                    options: {
                        auth_type: ("oauth" | "basic")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    };
                    type: "oauth";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                }>, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                    type: z.ZodString;
                    field: z.ZodString;
                    label: z.ZodString;
                    help: z.ZodOptional<z.ZodString>;
                    tooltip: z.ZodOptional<z.ZodString>;
                }, {
                    required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }>, {
                    type: z.ZodLiteral<"custom">;
                    options: z.ZodObject<{
                        type: z.ZodLiteral<"external">;
                        src: z.ZodString;
                        hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                    }, "strip", z.ZodTypeAny, {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    }, {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    }>;
                }>, "strip", z.ZodTypeAny, {
                    options: {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "custom";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                }, {
                    options: {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "custom";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                }>]>, "many">>;
                name: z.ZodString;
                title: z.ZodString;
                options: z.ZodOptional<z.ZodObject<{
                    saveValidator: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    saveValidator?: string | undefined;
                }, {
                    saveValidator?: string | undefined;
                }>>;
                table: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
                    moreInfo: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        field: z.ZodString;
                        label: z.ZodString;
                        mapping: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
                    }, "strip", z.ZodTypeAny, {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                    }, {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                    }>, "many">>;
                    header: z.ZodArray<z.ZodObject<{
                        field: z.ZodString;
                        label: z.ZodString;
                        mapping: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
                        customCell: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
                    }, "strip", z.ZodTypeAny, {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                        customCell?: Record<string, any> | undefined;
                    }, {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                        customCell?: Record<string, any> | undefined;
                    }>, "many">;
                    customRow: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
                    actions: z.ZodArray<z.ZodEnum<["edit", "delete", "clone", "search"]>, "many">;
                }, {
                    actions: z.ZodArray<z.ZodEnum<["edit", "delete", "clone"]>, "many">;
                }>, "strip", z.ZodTypeAny, {
                    header: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                        customCell?: Record<string, any> | undefined;
                    }[];
                    actions: ("clone" | "delete" | "edit")[];
                    moreInfo?: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                    }[] | undefined;
                    customRow?: Record<string, any> | undefined;
                }, {
                    header: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                        customCell?: Record<string, any> | undefined;
                    }[];
                    actions: ("clone" | "delete" | "edit")[];
                    moreInfo?: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                    }[] | undefined;
                    customRow?: Record<string, any> | undefined;
                }>>;
                style: z.ZodOptional<z.ZodEnum<["page", "dialog"]>>;
                hook: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
                conf: z.ZodOptional<z.ZodString>;
                restHandlerName: z.ZodOptional<z.ZodString>;
                restHandlerModule: z.ZodOptional<z.ZodString>;
                restHandlerClass: z.ZodOptional<z.ZodString>;
                customTab: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
                warning: z.ZodOptional<z.ZodObject<{
                    create: z.ZodOptional<z.ZodObject<{
                        message: z.ZodString;
                        alwaysDisplay: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    }, "strip", z.ZodTypeAny, {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    }, {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    }>>;
                    edit: z.ZodOptional<z.ZodObject<{
                        message: z.ZodString;
                        alwaysDisplay: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    }, "strip", z.ZodTypeAny, {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    }, {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    }>>;
                    config: z.ZodOptional<z.ZodObject<{
                        message: z.ZodString;
                        alwaysDisplay: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    }, "strip", z.ZodTypeAny, {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    }, {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    }>>;
                    clone: z.ZodOptional<z.ZodObject<{
                        message: z.ZodString;
                        alwaysDisplay: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    }, "strip", z.ZodTypeAny, {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    }, {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    }>>;
                }, "strip", z.ZodTypeAny, {
                    clone?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    create?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    edit?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    config?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                }, {
                    clone?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    create?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    edit?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    config?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                }>>;
                hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                groups: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    options: z.ZodOptional<z.ZodObject<{
                        isExpandable: z.ZodOptional<z.ZodBoolean>;
                        expand: z.ZodOptional<z.ZodBoolean>;
                    }, "strip", z.ZodTypeAny, {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    }, {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    }>>;
                    label: z.ZodString;
                    fields: z.ZodArray<z.ZodString, "many">;
                }, "strip", z.ZodTypeAny, {
                    label: string;
                    fields: string[];
                    options?: {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    } | undefined;
                }, {
                    label: string;
                    fields: string[];
                    options?: {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    } | undefined;
                }>, "many">>;
            }, "strip", z.ZodTypeAny, {
                name: string;
                title: string;
                options?: {
                    saveValidator?: string | undefined;
                } | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                groups?: {
                    label: string;
                    fields: string[];
                    options?: {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    } | undefined;
                }[] | undefined;
                entity?: ({
                    options: {
                        text: string;
                        link: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "helpLink";
                    field: string;
                    label?: string | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: false | undefined;
                } | {
                    type: "text";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "textarea";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    };
                    type: "singleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    };
                    type: "multipleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "checkbox";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxGroup";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxTree";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "radio";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "file";
                    label: string;
                    field: string;
                    options?: {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        auth_type: ("oauth" | "basic")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    };
                    type: "oauth";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                } | {
                    options: {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "custom";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                })[] | undefined;
                table?: {
                    header: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                        customCell?: Record<string, any> | undefined;
                    }[];
                    actions: ("clone" | "delete" | "edit")[];
                    moreInfo?: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                    }[] | undefined;
                    customRow?: Record<string, any> | undefined;
                } | undefined;
                style?: "page" | "dialog" | undefined;
                hook?: Record<string, any> | undefined;
                conf?: string | undefined;
                restHandlerName?: string | undefined;
                restHandlerModule?: string | undefined;
                restHandlerClass?: string | undefined;
                customTab?: Record<string, any> | undefined;
                warning?: {
                    clone?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    create?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    edit?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    config?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                } | undefined;
            }, {
                name: string;
                title: string;
                options?: {
                    saveValidator?: string | undefined;
                } | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                groups?: {
                    label: string;
                    fields: string[];
                    options?: {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    } | undefined;
                }[] | undefined;
                entity?: ({
                    options: {
                        text: string;
                        link: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "helpLink";
                    field: string;
                    label?: string | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: false | undefined;
                } | {
                    type: "text";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "textarea";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    };
                    type: "singleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    };
                    type: "multipleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "checkbox";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxGroup";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxTree";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "radio";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "file";
                    label: string;
                    field: string;
                    options?: {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        auth_type: ("oauth" | "basic")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    };
                    type: "oauth";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                } | {
                    options: {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "custom";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                })[] | undefined;
                table?: {
                    header: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                        customCell?: Record<string, any> | undefined;
                    }[];
                    actions: ("clone" | "delete" | "edit")[];
                    moreInfo?: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                    }[] | undefined;
                    customRow?: Record<string, any> | undefined;
                } | undefined;
                style?: "page" | "dialog" | undefined;
                hook?: Record<string, any> | undefined;
                conf?: string | undefined;
                restHandlerName?: string | undefined;
                restHandlerModule?: string | undefined;
                restHandlerClass?: string | undefined;
                customTab?: Record<string, any> | undefined;
                warning?: {
                    clone?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    create?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    edit?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    config?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                } | undefined;
            }>, "many">;
        }, "strip", z.ZodTypeAny, {
            title: string;
            tabs: {
                name: string;
                title: string;
                options?: {
                    saveValidator?: string | undefined;
                } | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                groups?: {
                    label: string;
                    fields: string[];
                    options?: {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    } | undefined;
                }[] | undefined;
                entity?: ({
                    options: {
                        text: string;
                        link: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "helpLink";
                    field: string;
                    label?: string | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: false | undefined;
                } | {
                    type: "text";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "textarea";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    };
                    type: "singleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    };
                    type: "multipleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "checkbox";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxGroup";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxTree";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "radio";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "file";
                    label: string;
                    field: string;
                    options?: {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        auth_type: ("oauth" | "basic")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    };
                    type: "oauth";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                } | {
                    options: {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "custom";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                })[] | undefined;
                table?: {
                    header: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                        customCell?: Record<string, any> | undefined;
                    }[];
                    actions: ("clone" | "delete" | "edit")[];
                    moreInfo?: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                    }[] | undefined;
                    customRow?: Record<string, any> | undefined;
                } | undefined;
                style?: "page" | "dialog" | undefined;
                hook?: Record<string, any> | undefined;
                conf?: string | undefined;
                restHandlerName?: string | undefined;
                restHandlerModule?: string | undefined;
                restHandlerClass?: string | undefined;
                customTab?: Record<string, any> | undefined;
                warning?: {
                    clone?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    create?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    edit?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    config?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                } | undefined;
            }[];
            description?: string | undefined;
            subDescription?: {
                text: string;
                links?: {
                    linkText: string;
                    link: string;
                    slug: string;
                }[] | undefined;
            } | undefined;
        }, {
            title: string;
            tabs: {
                name: string;
                title: string;
                options?: {
                    saveValidator?: string | undefined;
                } | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                groups?: {
                    label: string;
                    fields: string[];
                    options?: {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    } | undefined;
                }[] | undefined;
                entity?: ({
                    options: {
                        text: string;
                        link: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "helpLink";
                    field: string;
                    label?: string | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: false | undefined;
                } | {
                    type: "text";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "textarea";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    };
                    type: "singleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    };
                    type: "multipleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "checkbox";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxGroup";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxTree";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "radio";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "file";
                    label: string;
                    field: string;
                    options?: {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        auth_type: ("oauth" | "basic")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    };
                    type: "oauth";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                } | {
                    options: {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "custom";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                })[] | undefined;
                table?: {
                    header: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                        customCell?: Record<string, any> | undefined;
                    }[];
                    actions: ("clone" | "delete" | "edit")[];
                    moreInfo?: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                    }[] | undefined;
                    customRow?: Record<string, any> | undefined;
                } | undefined;
                style?: "page" | "dialog" | undefined;
                hook?: Record<string, any> | undefined;
                conf?: string | undefined;
                restHandlerName?: string | undefined;
                restHandlerModule?: string | undefined;
                restHandlerClass?: string | undefined;
                customTab?: Record<string, any> | undefined;
                warning?: {
                    clone?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    create?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    edit?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    config?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                } | undefined;
            }[];
            description?: string | undefined;
            subDescription?: {
                text: string;
                links?: {
                    linkText: string;
                    link: string;
                    slug: string;
                }[] | undefined;
            } | undefined;
        }>;
        inputs: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
            title: z.ZodString;
            services: z.ZodArray<z.ZodObject<z.objectUtil.extendShape<{
                name: z.ZodString;
                title: z.ZodString;
                subTitle: z.ZodOptional<z.ZodString>;
                entity: z.ZodArray<z.ZodDiscriminatedUnion<"type", [z.ZodObject<z.objectUtil.extendShape<{
                    type: z.ZodString;
                    field: z.ZodString;
                    label: z.ZodString;
                    help: z.ZodOptional<z.ZodString>;
                    tooltip: z.ZodOptional<z.ZodString>;
                }, {
                    type: z.ZodLiteral<"helpLink">;
                    label: z.ZodOptional<z.ZodString>;
                    options: z.ZodObject<{
                        text: z.ZodString;
                        link: z.ZodString;
                        hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                    }, "strip", z.ZodTypeAny, {
                        text: string;
                        link: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    }, {
                        text: string;
                        link: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    }>;
                    required: z.ZodOptional<z.ZodDefault<z.ZodLiteral<false>>>;
                }>, "strip", z.ZodTypeAny, {
                    options: {
                        text: string;
                        link: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "helpLink";
                    field: string;
                    label?: string | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: false | undefined;
                }, {
                    options: {
                        text: string;
                        link: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "helpLink";
                    field: string;
                    label?: string | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: false | undefined;
                }>, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                    type: z.ZodString;
                    field: z.ZodString;
                    label: z.ZodString;
                    help: z.ZodOptional<z.ZodString>;
                    tooltip: z.ZodOptional<z.ZodString>;
                }, {
                    required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }>, {
                    type: z.ZodLiteral<"text">;
                    validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"number">;
                        range: z.ZodArray<z.ZodNumber, "many">;
                        isInteger: z.ZodOptional<z.ZodBoolean>;
                    }, "strip", z.ZodTypeAny, {
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    }, {
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"string">;
                        minLength: z.ZodNumber;
                        maxLength: z.ZodNumber;
                    }, "strip", z.ZodTypeAny, {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    }, {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"regex">;
                        pattern: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"email">;
                    }, "strip", z.ZodTypeAny, {
                        type: "email";
                        errorMsg?: string | undefined;
                    }, {
                        type: "email";
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"ipv4">;
                    }, "strip", z.ZodTypeAny, {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    }, {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"url">;
                    }, "strip", z.ZodTypeAny, {
                        type: "url";
                        errorMsg?: string | undefined;
                    }, {
                        type: "url";
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"date">;
                    }, "strip", z.ZodTypeAny, {
                        type: "date";
                        errorMsg?: string | undefined;
                    }, {
                        type: "date";
                        errorMsg?: string | undefined;
                    }>]>, "many">>;
                    defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
                    options: z.ZodOptional<z.ZodObject<{
                        display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                    }, "strip", z.ZodTypeAny, {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    }, {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    }>>;
                    modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                        mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                        fieldsToModify: z.ZodArray<z.ZodObject<{
                            fieldId: z.ZodString;
                            display: z.ZodOptional<z.ZodBoolean>;
                            value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                            disabled: z.ZodOptional<z.ZodBoolean>;
                            required: z.ZodOptional<z.ZodBoolean>;
                            help: z.ZodOptional<z.ZodString>;
                            label: z.ZodOptional<z.ZodString>;
                            markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                                markdownType: z.ZodLiteral<"text">;
                                text: z.ZodString;
                                color: z.ZodOptional<z.ZodString>;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"hybrid">;
                                text: z.ZodString;
                                token: z.ZodString;
                                linkText: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"link">;
                                text: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodOptional<z.ZodUndefined>;
                                text: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                text: string;
                                markdownType?: undefined;
                            }, {
                                text: string;
                                markdownType?: undefined;
                            }>]>>;
                        }, "strip", z.ZodTypeAny, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }>, "many">;
                    }, "strip", z.ZodTypeAny, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }>, "many">>;
                }>, "strip", z.ZodTypeAny, {
                    type: "text";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }, {
                    type: "text";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }>, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                    type: z.ZodString;
                    field: z.ZodString;
                    label: z.ZodString;
                    help: z.ZodOptional<z.ZodString>;
                    tooltip: z.ZodOptional<z.ZodString>;
                }, {
                    required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }>, {
                    type: z.ZodLiteral<"textarea">;
                    validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"number">;
                        range: z.ZodArray<z.ZodNumber, "many">;
                        isInteger: z.ZodOptional<z.ZodBoolean>;
                    }, "strip", z.ZodTypeAny, {
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    }, {
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"string">;
                        minLength: z.ZodNumber;
                        maxLength: z.ZodNumber;
                    }, "strip", z.ZodTypeAny, {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    }, {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"regex">;
                        pattern: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"email">;
                    }, "strip", z.ZodTypeAny, {
                        type: "email";
                        errorMsg?: string | undefined;
                    }, {
                        type: "email";
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"ipv4">;
                    }, "strip", z.ZodTypeAny, {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    }, {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"url">;
                    }, "strip", z.ZodTypeAny, {
                        type: "url";
                        errorMsg?: string | undefined;
                    }, {
                        type: "url";
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"date">;
                    }, "strip", z.ZodTypeAny, {
                        type: "date";
                        errorMsg?: string | undefined;
                    }, {
                        type: "date";
                        errorMsg?: string | undefined;
                    }>]>, "many">>;
                    defaultValue: z.ZodOptional<z.ZodString>;
                    options: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
                        display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                    }, {
                        rowsMin: z.ZodOptional<z.ZodNumber>;
                        rowsMax: z.ZodOptional<z.ZodNumber>;
                    }>, "strip", z.ZodTypeAny, {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    }, {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    }>>;
                    modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                        mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                        fieldsToModify: z.ZodArray<z.ZodObject<{
                            fieldId: z.ZodString;
                            display: z.ZodOptional<z.ZodBoolean>;
                            value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                            disabled: z.ZodOptional<z.ZodBoolean>;
                            required: z.ZodOptional<z.ZodBoolean>;
                            help: z.ZodOptional<z.ZodString>;
                            label: z.ZodOptional<z.ZodString>;
                            markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                                markdownType: z.ZodLiteral<"text">;
                                text: z.ZodString;
                                color: z.ZodOptional<z.ZodString>;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"hybrid">;
                                text: z.ZodString;
                                token: z.ZodString;
                                linkText: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"link">;
                                text: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodOptional<z.ZodUndefined>;
                                text: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                text: string;
                                markdownType?: undefined;
                            }, {
                                text: string;
                                markdownType?: undefined;
                            }>]>>;
                        }, "strip", z.ZodTypeAny, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }>, "many">;
                    }, "strip", z.ZodTypeAny, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }>, "many">>;
                }>, "strip", z.ZodTypeAny, {
                    type: "textarea";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }, {
                    type: "textarea";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }>, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                    type: z.ZodString;
                    field: z.ZodString;
                    label: z.ZodString;
                    help: z.ZodOptional<z.ZodString>;
                    tooltip: z.ZodOptional<z.ZodString>;
                }, {
                    required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }>, {
                    type: z.ZodLiteral<"singleSelect">;
                    validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"number">;
                        range: z.ZodArray<z.ZodNumber, "many">;
                        isInteger: z.ZodOptional<z.ZodBoolean>;
                    }, "strip", z.ZodTypeAny, {
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    }, {
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"string">;
                        minLength: z.ZodNumber;
                        maxLength: z.ZodNumber;
                    }, "strip", z.ZodTypeAny, {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    }, {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"regex">;
                        pattern: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"email">;
                    }, "strip", z.ZodTypeAny, {
                        type: "email";
                        errorMsg?: string | undefined;
                    }, {
                        type: "email";
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"ipv4">;
                    }, "strip", z.ZodTypeAny, {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    }, {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"url">;
                    }, "strip", z.ZodTypeAny, {
                        type: "url";
                        errorMsg?: string | undefined;
                    }, {
                        type: "url";
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"date">;
                    }, "strip", z.ZodTypeAny, {
                        type: "date";
                        errorMsg?: string | undefined;
                    }, {
                        type: "date";
                        errorMsg?: string | undefined;
                    }>]>, "many">>;
                    defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
                    options: z.ZodObject<z.objectUtil.extendShape<{
                        display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                    }, {
                        disableSearch: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        createSearchChoice: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        referenceName: z.ZodOptional<z.ZodString>;
                        endpointUrl: z.ZodOptional<z.ZodString>;
                        allowList: z.ZodOptional<z.ZodString>;
                        denyList: z.ZodOptional<z.ZodString>;
                        labelField: z.ZodOptional<z.ZodString>;
                        valueField: z.ZodOptional<z.ZodString>;
                        autoCompleteFields: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                            value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                            label: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            value: string | number | boolean;
                            label: string;
                        }, {
                            value: string | number | boolean;
                            label: string;
                        }>, z.ZodObject<{
                            label: z.ZodString;
                            children: z.ZodArray<z.ZodObject<{
                                value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                                label: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                value: string | number | boolean;
                                label: string;
                            }, {
                                value: string | number | boolean;
                                label: string;
                            }>, "many">;
                        }, "strip", z.ZodTypeAny, {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        }, {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        }>]>, "many">>;
                        dependencies: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                        items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                            label: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            value: string | number | boolean;
                            label: string;
                        }, {
                            value: string | number | boolean;
                            label: string;
                        }>, "many">>;
                    }>, "strip", z.ZodTypeAny, {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    }, {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    }>;
                    modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                        mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                        fieldsToModify: z.ZodArray<z.ZodObject<{
                            fieldId: z.ZodString;
                            display: z.ZodOptional<z.ZodBoolean>;
                            value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                            disabled: z.ZodOptional<z.ZodBoolean>;
                            required: z.ZodOptional<z.ZodBoolean>;
                            help: z.ZodOptional<z.ZodString>;
                            label: z.ZodOptional<z.ZodString>;
                            markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                                markdownType: z.ZodLiteral<"text">;
                                text: z.ZodString;
                                color: z.ZodOptional<z.ZodString>;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"hybrid">;
                                text: z.ZodString;
                                token: z.ZodString;
                                linkText: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"link">;
                                text: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodOptional<z.ZodUndefined>;
                                text: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                text: string;
                                markdownType?: undefined;
                            }, {
                                text: string;
                                markdownType?: undefined;
                            }>]>>;
                        }, "strip", z.ZodTypeAny, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }>, "many">;
                    }, "strip", z.ZodTypeAny, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }>, "many">>;
                }>, "strip", z.ZodTypeAny, {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    };
                    type: "singleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }, {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    };
                    type: "singleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }>, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                    type: z.ZodString;
                    field: z.ZodString;
                    label: z.ZodString;
                    help: z.ZodOptional<z.ZodString>;
                    tooltip: z.ZodOptional<z.ZodString>;
                }, {
                    required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }>, {
                    type: z.ZodLiteral<"multipleSelect">;
                    validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"number">;
                        range: z.ZodArray<z.ZodNumber, "many">;
                        isInteger: z.ZodOptional<z.ZodBoolean>;
                    }, "strip", z.ZodTypeAny, {
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    }, {
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"string">;
                        minLength: z.ZodNumber;
                        maxLength: z.ZodNumber;
                    }, "strip", z.ZodTypeAny, {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    }, {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"regex">;
                        pattern: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"email">;
                    }, "strip", z.ZodTypeAny, {
                        type: "email";
                        errorMsg?: string | undefined;
                    }, {
                        type: "email";
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"ipv4">;
                    }, "strip", z.ZodTypeAny, {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    }, {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"url">;
                    }, "strip", z.ZodTypeAny, {
                        type: "url";
                        errorMsg?: string | undefined;
                    }, {
                        type: "url";
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"date">;
                    }, "strip", z.ZodTypeAny, {
                        type: "date";
                        errorMsg?: string | undefined;
                    }, {
                        type: "date";
                        errorMsg?: string | undefined;
                    }>]>, "many">>;
                    defaultValue: z.ZodOptional<z.ZodString>;
                    options: z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                        display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                    }, {
                        disableSearch: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        createSearchChoice: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        referenceName: z.ZodOptional<z.ZodString>;
                        endpointUrl: z.ZodOptional<z.ZodString>;
                        allowList: z.ZodOptional<z.ZodString>;
                        denyList: z.ZodOptional<z.ZodString>;
                        labelField: z.ZodOptional<z.ZodString>;
                        valueField: z.ZodOptional<z.ZodString>;
                        autoCompleteFields: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                            value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                            label: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            value: string | number | boolean;
                            label: string;
                        }, {
                            value: string | number | boolean;
                            label: string;
                        }>, z.ZodObject<{
                            label: z.ZodString;
                            children: z.ZodArray<z.ZodObject<{
                                value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                                label: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                value: string | number | boolean;
                                label: string;
                            }, {
                                value: string | number | boolean;
                                label: string;
                            }>, "many">;
                        }, "strip", z.ZodTypeAny, {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        }, {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        }>]>, "many">>;
                        dependencies: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                        items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                            label: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            value: string | number | boolean;
                            label: string;
                        }, {
                            value: string | number | boolean;
                            label: string;
                        }>, "many">>;
                    }>, {
                        delimiter: z.ZodOptional<z.ZodString>;
                    }>, "strip", z.ZodTypeAny, {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    }, {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    }>;
                    modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                        mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                        fieldsToModify: z.ZodArray<z.ZodObject<{
                            fieldId: z.ZodString;
                            display: z.ZodOptional<z.ZodBoolean>;
                            value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                            disabled: z.ZodOptional<z.ZodBoolean>;
                            required: z.ZodOptional<z.ZodBoolean>;
                            help: z.ZodOptional<z.ZodString>;
                            label: z.ZodOptional<z.ZodString>;
                            markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                                markdownType: z.ZodLiteral<"text">;
                                text: z.ZodString;
                                color: z.ZodOptional<z.ZodString>;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"hybrid">;
                                text: z.ZodString;
                                token: z.ZodString;
                                linkText: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"link">;
                                text: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodOptional<z.ZodUndefined>;
                                text: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                text: string;
                                markdownType?: undefined;
                            }, {
                                text: string;
                                markdownType?: undefined;
                            }>]>>;
                        }, "strip", z.ZodTypeAny, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }>, "many">;
                    }, "strip", z.ZodTypeAny, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }>, "many">>;
                }>, "strip", z.ZodTypeAny, {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    };
                    type: "multipleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }, {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    };
                    type: "multipleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }>, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                    type: z.ZodString;
                    field: z.ZodString;
                    label: z.ZodString;
                    help: z.ZodOptional<z.ZodString>;
                    tooltip: z.ZodOptional<z.ZodString>;
                }, {
                    required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }>, {
                    type: z.ZodLiteral<"checkbox">;
                    defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodBoolean]>>;
                    options: z.ZodOptional<z.ZodObject<{
                        display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                    }, "strip", z.ZodTypeAny, {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    }, {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    }>>;
                    modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                        mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                        fieldsToModify: z.ZodArray<z.ZodObject<{
                            fieldId: z.ZodString;
                            display: z.ZodOptional<z.ZodBoolean>;
                            value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                            disabled: z.ZodOptional<z.ZodBoolean>;
                            required: z.ZodOptional<z.ZodBoolean>;
                            help: z.ZodOptional<z.ZodString>;
                            label: z.ZodOptional<z.ZodString>;
                            markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                                markdownType: z.ZodLiteral<"text">;
                                text: z.ZodString;
                                color: z.ZodOptional<z.ZodString>;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"hybrid">;
                                text: z.ZodString;
                                token: z.ZodString;
                                linkText: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"link">;
                                text: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodOptional<z.ZodUndefined>;
                                text: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                text: string;
                                markdownType?: undefined;
                            }, {
                                text: string;
                                markdownType?: undefined;
                            }>]>>;
                        }, "strip", z.ZodTypeAny, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }>, "many">;
                    }, "strip", z.ZodTypeAny, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }>, "many">>;
                }>, "strip", z.ZodTypeAny, {
                    type: "checkbox";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }, {
                    type: "checkbox";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }>, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                    type: z.ZodString;
                    field: z.ZodString;
                    label: z.ZodString;
                    help: z.ZodOptional<z.ZodString>;
                    tooltip: z.ZodOptional<z.ZodString>;
                }, {
                    required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }>, {
                    type: z.ZodLiteral<"checkboxGroup">;
                    validators: z.ZodOptional<z.ZodTuple<[z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"regex">;
                        pattern: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }>], null>>;
                    defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodBoolean]>>;
                    options: z.ZodObject<z.objectUtil.extendShape<{
                        display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                    }, {
                        groups: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            label: z.ZodString;
                            fields: z.ZodArray<z.ZodString, "many">;
                            options: z.ZodOptional<z.ZodObject<{
                                isExpandable: z.ZodOptional<z.ZodBoolean>;
                                expand: z.ZodOptional<z.ZodBoolean>;
                            }, "strip", z.ZodTypeAny, {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            }, {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            }>>;
                        }, "strip", z.ZodTypeAny, {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }, {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }>, "many">>;
                        rows: z.ZodArray<z.ZodObject<{
                            field: z.ZodString;
                            checkbox: z.ZodOptional<z.ZodObject<{
                                label: z.ZodOptional<z.ZodString>;
                                defaultValue: z.ZodOptional<z.ZodBoolean>;
                            }, "strip", z.ZodTypeAny, {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            }, {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            }>>;
                            input: z.ZodOptional<z.ZodObject<{
                                defaultValue: z.ZodOptional<z.ZodNumber>;
                                validators: z.ZodOptional<z.ZodTuple<[z.ZodObject<{
                                    errorMsg: z.ZodOptional<z.ZodString>;
                                    type: z.ZodLiteral<"number">;
                                    range: z.ZodArray<z.ZodNumber, "many">;
                                    isInteger: z.ZodOptional<z.ZodBoolean>;
                                }, "strip", z.ZodTypeAny, {
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }, {
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }>], null>>;
                                required: z.ZodOptional<z.ZodBoolean>;
                            }, "strip", z.ZodTypeAny, {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            }, {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            }>>;
                        }, "strip", z.ZodTypeAny, {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }, {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }>, "many">;
                    }>, "strip", z.ZodTypeAny, {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    }, {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    }>;
                }>, "strip", z.ZodTypeAny, {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxGroup";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                }, {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxGroup";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                }>, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                    type: z.ZodString;
                    field: z.ZodString;
                    label: z.ZodString;
                    help: z.ZodOptional<z.ZodString>;
                    tooltip: z.ZodOptional<z.ZodString>;
                }, {
                    required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }>, {
                    type: z.ZodLiteral<"checkboxTree">;
                    validators: z.ZodOptional<z.ZodTuple<[z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"regex">;
                        pattern: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }>], null>>;
                    defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodBoolean]>>;
                    options: z.ZodObject<z.objectUtil.extendShape<{
                        display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                    }, {
                        groups: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            label: z.ZodString;
                            fields: z.ZodArray<z.ZodString, "many">;
                            options: z.ZodOptional<z.ZodObject<{
                                isExpandable: z.ZodOptional<z.ZodBoolean>;
                                expand: z.ZodOptional<z.ZodBoolean>;
                            }, "strip", z.ZodTypeAny, {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            }, {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            }>>;
                        }, "strip", z.ZodTypeAny, {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }, {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }>, "many">>;
                        rows: z.ZodArray<z.ZodObject<{
                            field: z.ZodString;
                            checkbox: z.ZodOptional<z.ZodObject<{
                                label: z.ZodOptional<z.ZodString>;
                                defaultValue: z.ZodOptional<z.ZodBoolean>;
                            }, "strip", z.ZodTypeAny, {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            }, {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            }>>;
                        }, "strip", z.ZodTypeAny, {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }, {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }>, "many">;
                    }>, "strip", z.ZodTypeAny, {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    }, {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    }>;
                }>, "strip", z.ZodTypeAny, {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxTree";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                }, {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxTree";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                }>, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                    type: z.ZodString;
                    field: z.ZodString;
                    label: z.ZodString;
                    help: z.ZodOptional<z.ZodString>;
                    tooltip: z.ZodOptional<z.ZodString>;
                }, {
                    required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }>, {
                    type: z.ZodLiteral<"radio">;
                    defaultValue: z.ZodOptional<z.ZodString>;
                    options: z.ZodObject<z.objectUtil.extendShape<{
                        display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                    }, {
                        items: z.ZodArray<z.ZodObject<{
                            value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                            label: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            value: string | number | boolean;
                            label: string;
                        }, {
                            value: string | number | boolean;
                            label: string;
                        }>, "many">;
                    }>, "strip", z.ZodTypeAny, {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    }, {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    }>;
                    modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                        mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                        fieldsToModify: z.ZodArray<z.ZodObject<{
                            fieldId: z.ZodString;
                            display: z.ZodOptional<z.ZodBoolean>;
                            value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                            disabled: z.ZodOptional<z.ZodBoolean>;
                            required: z.ZodOptional<z.ZodBoolean>;
                            help: z.ZodOptional<z.ZodString>;
                            label: z.ZodOptional<z.ZodString>;
                            markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                                markdownType: z.ZodLiteral<"text">;
                                text: z.ZodString;
                                color: z.ZodOptional<z.ZodString>;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"hybrid">;
                                text: z.ZodString;
                                token: z.ZodString;
                                linkText: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"link">;
                                text: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodOptional<z.ZodUndefined>;
                                text: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                text: string;
                                markdownType?: undefined;
                            }, {
                                text: string;
                                markdownType?: undefined;
                            }>]>>;
                        }, "strip", z.ZodTypeAny, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }>, "many">;
                    }, "strip", z.ZodTypeAny, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }>, "many">>;
                }>, "strip", z.ZodTypeAny, {
                    options: {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "radio";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }, {
                    options: {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "radio";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }>, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                    type: z.ZodString;
                    field: z.ZodString;
                    label: z.ZodString;
                    help: z.ZodOptional<z.ZodString>;
                    tooltip: z.ZodOptional<z.ZodString>;
                }, {
                    required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }>, {
                    type: z.ZodLiteral<"file">;
                    defaultValue: z.ZodOptional<z.ZodString>;
                    validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"string">;
                        minLength: z.ZodNumber;
                        maxLength: z.ZodNumber;
                    }, "strip", z.ZodTypeAny, {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    }, {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"regex">;
                        pattern: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }>]>, "many">>;
                    options: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
                        display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                    }, {
                        maxFileSize: z.ZodOptional<z.ZodNumber>;
                        fileSupportMessage: z.ZodOptional<z.ZodString>;
                        supportedFileTypes: z.ZodArray<z.ZodString, "many">;
                        useBase64Encoding: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    }>, "strip", z.ZodTypeAny, {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    }, {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    }>>;
                    modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                        mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                        fieldsToModify: z.ZodArray<z.ZodObject<{
                            fieldId: z.ZodString;
                            display: z.ZodOptional<z.ZodBoolean>;
                            value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                            disabled: z.ZodOptional<z.ZodBoolean>;
                            required: z.ZodOptional<z.ZodBoolean>;
                            help: z.ZodOptional<z.ZodString>;
                            label: z.ZodOptional<z.ZodString>;
                            markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                                markdownType: z.ZodLiteral<"text">;
                                text: z.ZodString;
                                color: z.ZodOptional<z.ZodString>;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"hybrid">;
                                text: z.ZodString;
                                token: z.ZodString;
                                linkText: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"link">;
                                text: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodOptional<z.ZodUndefined>;
                                text: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                text: string;
                                markdownType?: undefined;
                            }, {
                                text: string;
                                markdownType?: undefined;
                            }>]>>;
                        }, "strip", z.ZodTypeAny, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }>, "many">;
                    }, "strip", z.ZodTypeAny, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }>, "many">>;
                }>, "strip", z.ZodTypeAny, {
                    type: "file";
                    label: string;
                    field: string;
                    options?: {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }, {
                    type: "file";
                    label: string;
                    field: string;
                    options?: {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }>, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                    type: z.ZodString;
                    field: z.ZodString;
                    label: z.ZodString;
                    help: z.ZodOptional<z.ZodString>;
                    tooltip: z.ZodOptional<z.ZodString>;
                }, {
                    required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }>, {
                    type: z.ZodLiteral<"oauth">;
                    defaultValue: z.ZodOptional<z.ZodString>;
                    validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"string">;
                        minLength: z.ZodNumber;
                        maxLength: z.ZodNumber;
                    }, "strip", z.ZodTypeAny, {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    }, {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"regex">;
                        pattern: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }>]>, "many">>;
                    options: z.ZodObject<z.objectUtil.extendShape<Omit<{
                        display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                    }, "requiredWhenVisible">, {
                        auth_type: z.ZodArray<z.ZodUnion<[z.ZodLiteral<"basic">, z.ZodLiteral<"oauth">]>, "many">;
                        basic: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            oauth_field: z.ZodString;
                            label: z.ZodString;
                            field: z.ZodString;
                            type: z.ZodOptional<z.ZodDefault<z.ZodLiteral<"text">>>;
                            help: z.ZodString;
                            encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
                            options: z.ZodOptional<z.ZodObject<{
                                display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                                disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                                enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                                requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                                hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                            }, "strip", z.ZodTypeAny, {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            }, {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            }>>;
                            modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                                mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                                fieldsToModify: z.ZodArray<z.ZodObject<{
                                    fieldId: z.ZodString;
                                    display: z.ZodOptional<z.ZodBoolean>;
                                    value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                                    disabled: z.ZodOptional<z.ZodBoolean>;
                                    required: z.ZodOptional<z.ZodBoolean>;
                                    help: z.ZodOptional<z.ZodString>;
                                    label: z.ZodOptional<z.ZodString>;
                                    markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                                        markdownType: z.ZodLiteral<"text">;
                                        text: z.ZodString;
                                        color: z.ZodOptional<z.ZodString>;
                                    }, "strip", z.ZodTypeAny, {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    }, {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    }>, z.ZodObject<{
                                        markdownType: z.ZodLiteral<"hybrid">;
                                        text: z.ZodString;
                                        token: z.ZodString;
                                        linkText: z.ZodString;
                                        link: z.ZodString;
                                    }, "strip", z.ZodTypeAny, {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    }, {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    }>, z.ZodObject<{
                                        markdownType: z.ZodLiteral<"link">;
                                        text: z.ZodString;
                                        link: z.ZodString;
                                    }, "strip", z.ZodTypeAny, {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    }, {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    }>, z.ZodObject<{
                                        markdownType: z.ZodOptional<z.ZodUndefined>;
                                        text: z.ZodString;
                                    }, "strip", z.ZodTypeAny, {
                                        text: string;
                                        markdownType?: undefined;
                                    }, {
                                        text: string;
                                        markdownType?: undefined;
                                    }>]>>;
                                }, "strip", z.ZodTypeAny, {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }, {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }>, "many">;
                            }, "strip", z.ZodTypeAny, {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }, {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }>, "many">>;
                            validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"number">;
                                range: z.ZodArray<z.ZodNumber, "many">;
                                isInteger: z.ZodOptional<z.ZodBoolean>;
                            }, "strip", z.ZodTypeAny, {
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }, {
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }>, z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"string">;
                                minLength: z.ZodNumber;
                                maxLength: z.ZodNumber;
                            }, "strip", z.ZodTypeAny, {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            }, {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            }>, z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"regex">;
                                pattern: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            }, {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            }>, z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"email">;
                            }, "strip", z.ZodTypeAny, {
                                type: "email";
                                errorMsg?: string | undefined;
                            }, {
                                type: "email";
                                errorMsg?: string | undefined;
                            }>, z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"ipv4">;
                            }, "strip", z.ZodTypeAny, {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            }, {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            }>, z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"url">;
                            }, "strip", z.ZodTypeAny, {
                                type: "url";
                                errorMsg?: string | undefined;
                            }, {
                                type: "url";
                                errorMsg?: string | undefined;
                            }>, z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"date">;
                            }, "strip", z.ZodTypeAny, {
                                type: "date";
                                errorMsg?: string | undefined;
                            }, {
                                type: "date";
                                errorMsg?: string | undefined;
                            }>]>, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }, {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }>, "many">>;
                        oauth: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            oauth_field: z.ZodString;
                            label: z.ZodString;
                            field: z.ZodString;
                            type: z.ZodOptional<z.ZodDefault<z.ZodLiteral<"text">>>;
                            help: z.ZodString;
                            encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
                            options: z.ZodOptional<z.ZodObject<{
                                display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                                disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                                enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                                requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                                hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                            }, "strip", z.ZodTypeAny, {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            }, {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            }>>;
                            modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                                mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                                fieldsToModify: z.ZodArray<z.ZodObject<{
                                    fieldId: z.ZodString;
                                    display: z.ZodOptional<z.ZodBoolean>;
                                    value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                                    disabled: z.ZodOptional<z.ZodBoolean>;
                                    required: z.ZodOptional<z.ZodBoolean>;
                                    help: z.ZodOptional<z.ZodString>;
                                    label: z.ZodOptional<z.ZodString>;
                                    markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                                        markdownType: z.ZodLiteral<"text">;
                                        text: z.ZodString;
                                        color: z.ZodOptional<z.ZodString>;
                                    }, "strip", z.ZodTypeAny, {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    }, {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    }>, z.ZodObject<{
                                        markdownType: z.ZodLiteral<"hybrid">;
                                        text: z.ZodString;
                                        token: z.ZodString;
                                        linkText: z.ZodString;
                                        link: z.ZodString;
                                    }, "strip", z.ZodTypeAny, {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    }, {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    }>, z.ZodObject<{
                                        markdownType: z.ZodLiteral<"link">;
                                        text: z.ZodString;
                                        link: z.ZodString;
                                    }, "strip", z.ZodTypeAny, {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    }, {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    }>, z.ZodObject<{
                                        markdownType: z.ZodOptional<z.ZodUndefined>;
                                        text: z.ZodString;
                                    }, "strip", z.ZodTypeAny, {
                                        text: string;
                                        markdownType?: undefined;
                                    }, {
                                        text: string;
                                        markdownType?: undefined;
                                    }>]>>;
                                }, "strip", z.ZodTypeAny, {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }, {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }>, "many">;
                            }, "strip", z.ZodTypeAny, {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }, {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }>, "many">>;
                            validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"number">;
                                range: z.ZodArray<z.ZodNumber, "many">;
                                isInteger: z.ZodOptional<z.ZodBoolean>;
                            }, "strip", z.ZodTypeAny, {
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }, {
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }>, z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"string">;
                                minLength: z.ZodNumber;
                                maxLength: z.ZodNumber;
                            }, "strip", z.ZodTypeAny, {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            }, {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            }>, z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"regex">;
                                pattern: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            }, {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            }>, z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"email">;
                            }, "strip", z.ZodTypeAny, {
                                type: "email";
                                errorMsg?: string | undefined;
                            }, {
                                type: "email";
                                errorMsg?: string | undefined;
                            }>, z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"ipv4">;
                            }, "strip", z.ZodTypeAny, {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            }, {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            }>, z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"url">;
                            }, "strip", z.ZodTypeAny, {
                                type: "url";
                                errorMsg?: string | undefined;
                            }, {
                                type: "url";
                                errorMsg?: string | undefined;
                            }>, z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"date">;
                            }, "strip", z.ZodTypeAny, {
                                type: "date";
                                errorMsg?: string | undefined;
                            }, {
                                type: "date";
                                errorMsg?: string | undefined;
                            }>]>, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }, {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }>, "many">>;
                        auth_label: z.ZodOptional<z.ZodString>;
                        oauth_popup_width: z.ZodOptional<z.ZodNumber>;
                        oauth_popup_height: z.ZodOptional<z.ZodNumber>;
                        oauth_timeout: z.ZodOptional<z.ZodNumber>;
                        auth_code_endpoint: z.ZodOptional<z.ZodString>;
                        access_token_endpoint: z.ZodOptional<z.ZodString>;
                        oauth_state_enabled: z.ZodOptional<z.ZodBoolean>;
                        auth_endpoint_token_access_type: z.ZodOptional<z.ZodString>;
                    }>, "strip", z.ZodTypeAny, {
                        auth_type: ("oauth" | "basic")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    }, {
                        auth_type: ("oauth" | "basic")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    }>;
                }>, "strip", z.ZodTypeAny, {
                    options: {
                        auth_type: ("oauth" | "basic")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    };
                    type: "oauth";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                }, {
                    options: {
                        auth_type: ("oauth" | "basic")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    };
                    type: "oauth";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                }>, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                    type: z.ZodString;
                    field: z.ZodString;
                    label: z.ZodString;
                    help: z.ZodOptional<z.ZodString>;
                    tooltip: z.ZodOptional<z.ZodString>;
                }, {
                    required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }>, {
                    type: z.ZodLiteral<"custom">;
                    options: z.ZodObject<{
                        type: z.ZodLiteral<"external">;
                        src: z.ZodString;
                        hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                    }, "strip", z.ZodTypeAny, {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    }, {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    }>;
                }>, "strip", z.ZodTypeAny, {
                    options: {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "custom";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                }, {
                    options: {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "custom";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                }>]>, "many">;
                options: z.ZodOptional<z.ZodObject<{
                    saveValidator: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    saveValidator?: string | undefined;
                }, {
                    saveValidator?: string | undefined;
                }>>;
                groups: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    options: z.ZodOptional<z.ZodObject<{
                        isExpandable: z.ZodOptional<z.ZodBoolean>;
                        expand: z.ZodOptional<z.ZodBoolean>;
                    }, "strip", z.ZodTypeAny, {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    }, {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    }>>;
                    label: z.ZodString;
                    fields: z.ZodArray<z.ZodString, "many">;
                }, "strip", z.ZodTypeAny, {
                    label: string;
                    fields: string[];
                    options?: {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    } | undefined;
                }, {
                    label: string;
                    fields: string[];
                    options?: {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    } | undefined;
                }>, "many">>;
                style: z.ZodOptional<z.ZodEnum<["page", "dialog"]>>;
                hook: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
                conf: z.ZodOptional<z.ZodString>;
                restHandlerName: z.ZodOptional<z.ZodString>;
                restHandlerModule: z.ZodOptional<z.ZodString>;
                restHandlerClass: z.ZodOptional<z.ZodString>;
                warning: z.ZodOptional<z.ZodObject<{
                    create: z.ZodOptional<z.ZodObject<{
                        message: z.ZodString;
                        alwaysDisplay: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    }, "strip", z.ZodTypeAny, {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    }, {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    }>>;
                    edit: z.ZodOptional<z.ZodObject<{
                        message: z.ZodString;
                        alwaysDisplay: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    }, "strip", z.ZodTypeAny, {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    }, {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    }>>;
                    config: z.ZodOptional<z.ZodObject<{
                        message: z.ZodString;
                        alwaysDisplay: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    }, "strip", z.ZodTypeAny, {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    }, {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    }>>;
                    clone: z.ZodOptional<z.ZodObject<{
                        message: z.ZodString;
                        alwaysDisplay: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    }, "strip", z.ZodTypeAny, {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    }, {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    }>>;
                }, "strip", z.ZodTypeAny, {
                    clone?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    create?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    edit?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    config?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                }, {
                    clone?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    create?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    edit?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    config?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                }>>;
                inputHelperModule: z.ZodOptional<z.ZodString>;
                disableNewInput: z.ZodOptional<z.ZodBoolean>;
                hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
            }, {
                description: z.ZodOptional<z.ZodString>;
                table: z.ZodObject<{
                    moreInfo: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        field: z.ZodString;
                        label: z.ZodString;
                        mapping: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
                    }, "strip", z.ZodTypeAny, {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                    }, {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                    }>, "many">>;
                    header: z.ZodArray<z.ZodObject<{
                        field: z.ZodString;
                        label: z.ZodString;
                        mapping: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
                        customCell: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
                    }, "strip", z.ZodTypeAny, {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                        customCell?: Record<string, any> | undefined;
                    }, {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                        customCell?: Record<string, any> | undefined;
                    }>, "many">;
                    customRow: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
                    actions: z.ZodArray<z.ZodEnum<["edit", "delete", "clone", "search"]>, "many">;
                }, "strip", z.ZodTypeAny, {
                    header: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                        customCell?: Record<string, any> | undefined;
                    }[];
                    actions: ("clone" | "delete" | "edit" | "search")[];
                    moreInfo?: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                    }[] | undefined;
                    customRow?: Record<string, any> | undefined;
                }, {
                    header: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                        customCell?: Record<string, any> | undefined;
                    }[];
                    actions: ("clone" | "delete" | "edit" | "search")[];
                    moreInfo?: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                    }[] | undefined;
                    customRow?: Record<string, any> | undefined;
                }>;
                useInputToggleConfirmation: z.ZodOptional<z.ZodBoolean>;
            }>, "strip", z.ZodTypeAny, {
                name: string;
                entity: ({
                    options: {
                        text: string;
                        link: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "helpLink";
                    field: string;
                    label?: string | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: false | undefined;
                } | {
                    type: "text";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "textarea";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    };
                    type: "singleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    };
                    type: "multipleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "checkbox";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxGroup";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxTree";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "radio";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "file";
                    label: string;
                    field: string;
                    options?: {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        auth_type: ("oauth" | "basic")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    };
                    type: "oauth";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                } | {
                    options: {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "custom";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                })[];
                title: string;
                table: {
                    header: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                        customCell?: Record<string, any> | undefined;
                    }[];
                    actions: ("clone" | "delete" | "edit" | "search")[];
                    moreInfo?: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                    }[] | undefined;
                    customRow?: Record<string, any> | undefined;
                };
                options?: {
                    saveValidator?: string | undefined;
                } | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                groups?: {
                    label: string;
                    fields: string[];
                    options?: {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    } | undefined;
                }[] | undefined;
                style?: "page" | "dialog" | undefined;
                hook?: Record<string, any> | undefined;
                conf?: string | undefined;
                restHandlerName?: string | undefined;
                restHandlerModule?: string | undefined;
                restHandlerClass?: string | undefined;
                warning?: {
                    clone?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    create?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    edit?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    config?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                } | undefined;
                subTitle?: string | undefined;
                inputHelperModule?: string | undefined;
                disableNewInput?: boolean | undefined;
                description?: string | undefined;
                useInputToggleConfirmation?: boolean | undefined;
            }, {
                name: string;
                entity: ({
                    options: {
                        text: string;
                        link: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "helpLink";
                    field: string;
                    label?: string | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: false | undefined;
                } | {
                    type: "text";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "textarea";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    };
                    type: "singleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    };
                    type: "multipleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "checkbox";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxGroup";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxTree";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "radio";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "file";
                    label: string;
                    field: string;
                    options?: {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        auth_type: ("oauth" | "basic")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    };
                    type: "oauth";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                } | {
                    options: {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "custom";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                })[];
                title: string;
                table: {
                    header: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                        customCell?: Record<string, any> | undefined;
                    }[];
                    actions: ("clone" | "delete" | "edit" | "search")[];
                    moreInfo?: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                    }[] | undefined;
                    customRow?: Record<string, any> | undefined;
                };
                options?: {
                    saveValidator?: string | undefined;
                } | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                groups?: {
                    label: string;
                    fields: string[];
                    options?: {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    } | undefined;
                }[] | undefined;
                style?: "page" | "dialog" | undefined;
                hook?: Record<string, any> | undefined;
                conf?: string | undefined;
                restHandlerName?: string | undefined;
                restHandlerModule?: string | undefined;
                restHandlerClass?: string | undefined;
                warning?: {
                    clone?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    create?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    edit?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    config?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                } | undefined;
                subTitle?: string | undefined;
                inputHelperModule?: string | undefined;
                disableNewInput?: boolean | undefined;
                description?: string | undefined;
                useInputToggleConfirmation?: boolean | undefined;
            }>, "many">;
        }, "strict", z.ZodTypeAny, {
            title: string;
            services: {
                name: string;
                entity: ({
                    options: {
                        text: string;
                        link: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "helpLink";
                    field: string;
                    label?: string | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: false | undefined;
                } | {
                    type: "text";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "textarea";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    };
                    type: "singleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    };
                    type: "multipleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "checkbox";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxGroup";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxTree";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "radio";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "file";
                    label: string;
                    field: string;
                    options?: {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        auth_type: ("oauth" | "basic")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    };
                    type: "oauth";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                } | {
                    options: {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "custom";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                })[];
                title: string;
                table: {
                    header: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                        customCell?: Record<string, any> | undefined;
                    }[];
                    actions: ("clone" | "delete" | "edit" | "search")[];
                    moreInfo?: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                    }[] | undefined;
                    customRow?: Record<string, any> | undefined;
                };
                options?: {
                    saveValidator?: string | undefined;
                } | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                groups?: {
                    label: string;
                    fields: string[];
                    options?: {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    } | undefined;
                }[] | undefined;
                style?: "page" | "dialog" | undefined;
                hook?: Record<string, any> | undefined;
                conf?: string | undefined;
                restHandlerName?: string | undefined;
                restHandlerModule?: string | undefined;
                restHandlerClass?: string | undefined;
                warning?: {
                    clone?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    create?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    edit?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    config?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                } | undefined;
                subTitle?: string | undefined;
                inputHelperModule?: string | undefined;
                disableNewInput?: boolean | undefined;
                description?: string | undefined;
                useInputToggleConfirmation?: boolean | undefined;
            }[];
        }, {
            title: string;
            services: {
                name: string;
                entity: ({
                    options: {
                        text: string;
                        link: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "helpLink";
                    field: string;
                    label?: string | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: false | undefined;
                } | {
                    type: "text";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "textarea";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    };
                    type: "singleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    };
                    type: "multipleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "checkbox";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxGroup";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxTree";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "radio";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "file";
                    label: string;
                    field: string;
                    options?: {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        auth_type: ("oauth" | "basic")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    };
                    type: "oauth";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                } | {
                    options: {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "custom";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                })[];
                title: string;
                table: {
                    header: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                        customCell?: Record<string, any> | undefined;
                    }[];
                    actions: ("clone" | "delete" | "edit" | "search")[];
                    moreInfo?: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                    }[] | undefined;
                    customRow?: Record<string, any> | undefined;
                };
                options?: {
                    saveValidator?: string | undefined;
                } | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                groups?: {
                    label: string;
                    fields: string[];
                    options?: {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    } | undefined;
                }[] | undefined;
                style?: "page" | "dialog" | undefined;
                hook?: Record<string, any> | undefined;
                conf?: string | undefined;
                restHandlerName?: string | undefined;
                restHandlerModule?: string | undefined;
                restHandlerClass?: string | undefined;
                warning?: {
                    clone?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    create?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    edit?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    config?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                } | undefined;
                subTitle?: string | undefined;
                inputHelperModule?: string | undefined;
                disableNewInput?: boolean | undefined;
                description?: string | undefined;
                useInputToggleConfirmation?: boolean | undefined;
            }[];
        }>, z.ZodObject<{
            title: z.ZodString;
            description: z.ZodOptional<z.ZodString>;
            subDescription: z.ZodOptional<z.ZodObject<{
                text: z.ZodString;
                links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    slug: z.ZodString;
                    link: z.ZodString;
                    linkText: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    linkText: string;
                    link: string;
                    slug: string;
                }, {
                    linkText: string;
                    link: string;
                    slug: string;
                }>, "many">>;
            }, "strip", z.ZodTypeAny, {
                text: string;
                links?: {
                    linkText: string;
                    link: string;
                    slug: string;
                }[] | undefined;
            }, {
                text: string;
                links?: {
                    linkText: string;
                    link: string;
                    slug: string;
                }[] | undefined;
            }>>;
            menu: z.ZodOptional<z.ZodObject<{
                type: z.ZodLiteral<"external">;
                src: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                type: "external";
                src: string;
            }, {
                type: "external";
                src: string;
            }>>;
            table: z.ZodObject<{
                moreInfo: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    field: z.ZodString;
                    label: z.ZodString;
                    mapping: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
                }, "strip", z.ZodTypeAny, {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                }, {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                }>, "many">>;
                header: z.ZodArray<z.ZodObject<{
                    field: z.ZodString;
                    label: z.ZodString;
                    mapping: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
                    customCell: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
                }, "strip", z.ZodTypeAny, {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                    customCell?: Record<string, any> | undefined;
                }, {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                    customCell?: Record<string, any> | undefined;
                }>, "many">;
                customRow: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
                actions: z.ZodArray<z.ZodEnum<["edit", "delete", "clone", "search"]>, "many">;
            }, "strip", z.ZodTypeAny, {
                header: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                    customCell?: Record<string, any> | undefined;
                }[];
                actions: ("clone" | "delete" | "edit" | "search")[];
                moreInfo?: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                }[] | undefined;
                customRow?: Record<string, any> | undefined;
            }, {
                header: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                    customCell?: Record<string, any> | undefined;
                }[];
                actions: ("clone" | "delete" | "edit" | "search")[];
                moreInfo?: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                }[] | undefined;
                customRow?: Record<string, any> | undefined;
            }>;
            groupsMenu: z.ZodOptional<z.ZodArray<z.ZodObject<{
                groupName: z.ZodString;
                groupTitle: z.ZodString;
                groupServices: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
            }, "strip", z.ZodTypeAny, {
                groupName: string;
                groupTitle: string;
                groupServices?: string[] | undefined;
            }, {
                groupName: string;
                groupTitle: string;
                groupServices?: string[] | undefined;
            }>, "many">>;
            services: z.ZodArray<z.ZodObject<{
                name: z.ZodString;
                title: z.ZodString;
                subTitle: z.ZodOptional<z.ZodString>;
                entity: z.ZodArray<z.ZodDiscriminatedUnion<"type", [z.ZodObject<z.objectUtil.extendShape<{
                    type: z.ZodString;
                    field: z.ZodString;
                    label: z.ZodString;
                    help: z.ZodOptional<z.ZodString>;
                    tooltip: z.ZodOptional<z.ZodString>;
                }, {
                    type: z.ZodLiteral<"helpLink">;
                    label: z.ZodOptional<z.ZodString>;
                    options: z.ZodObject<{
                        text: z.ZodString;
                        link: z.ZodString;
                        hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                    }, "strip", z.ZodTypeAny, {
                        text: string;
                        link: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    }, {
                        text: string;
                        link: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    }>;
                    required: z.ZodOptional<z.ZodDefault<z.ZodLiteral<false>>>;
                }>, "strip", z.ZodTypeAny, {
                    options: {
                        text: string;
                        link: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "helpLink";
                    field: string;
                    label?: string | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: false | undefined;
                }, {
                    options: {
                        text: string;
                        link: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "helpLink";
                    field: string;
                    label?: string | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: false | undefined;
                }>, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                    type: z.ZodString;
                    field: z.ZodString;
                    label: z.ZodString;
                    help: z.ZodOptional<z.ZodString>;
                    tooltip: z.ZodOptional<z.ZodString>;
                }, {
                    required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }>, {
                    type: z.ZodLiteral<"text">;
                    validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"number">;
                        range: z.ZodArray<z.ZodNumber, "many">;
                        isInteger: z.ZodOptional<z.ZodBoolean>;
                    }, "strip", z.ZodTypeAny, {
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    }, {
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"string">;
                        minLength: z.ZodNumber;
                        maxLength: z.ZodNumber;
                    }, "strip", z.ZodTypeAny, {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    }, {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"regex">;
                        pattern: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"email">;
                    }, "strip", z.ZodTypeAny, {
                        type: "email";
                        errorMsg?: string | undefined;
                    }, {
                        type: "email";
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"ipv4">;
                    }, "strip", z.ZodTypeAny, {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    }, {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"url">;
                    }, "strip", z.ZodTypeAny, {
                        type: "url";
                        errorMsg?: string | undefined;
                    }, {
                        type: "url";
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"date">;
                    }, "strip", z.ZodTypeAny, {
                        type: "date";
                        errorMsg?: string | undefined;
                    }, {
                        type: "date";
                        errorMsg?: string | undefined;
                    }>]>, "many">>;
                    defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
                    options: z.ZodOptional<z.ZodObject<{
                        display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                    }, "strip", z.ZodTypeAny, {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    }, {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    }>>;
                    modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                        mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                        fieldsToModify: z.ZodArray<z.ZodObject<{
                            fieldId: z.ZodString;
                            display: z.ZodOptional<z.ZodBoolean>;
                            value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                            disabled: z.ZodOptional<z.ZodBoolean>;
                            required: z.ZodOptional<z.ZodBoolean>;
                            help: z.ZodOptional<z.ZodString>;
                            label: z.ZodOptional<z.ZodString>;
                            markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                                markdownType: z.ZodLiteral<"text">;
                                text: z.ZodString;
                                color: z.ZodOptional<z.ZodString>;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"hybrid">;
                                text: z.ZodString;
                                token: z.ZodString;
                                linkText: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"link">;
                                text: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodOptional<z.ZodUndefined>;
                                text: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                text: string;
                                markdownType?: undefined;
                            }, {
                                text: string;
                                markdownType?: undefined;
                            }>]>>;
                        }, "strip", z.ZodTypeAny, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }>, "many">;
                    }, "strip", z.ZodTypeAny, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }>, "many">>;
                }>, "strip", z.ZodTypeAny, {
                    type: "text";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }, {
                    type: "text";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }>, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                    type: z.ZodString;
                    field: z.ZodString;
                    label: z.ZodString;
                    help: z.ZodOptional<z.ZodString>;
                    tooltip: z.ZodOptional<z.ZodString>;
                }, {
                    required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }>, {
                    type: z.ZodLiteral<"textarea">;
                    validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"number">;
                        range: z.ZodArray<z.ZodNumber, "many">;
                        isInteger: z.ZodOptional<z.ZodBoolean>;
                    }, "strip", z.ZodTypeAny, {
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    }, {
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"string">;
                        minLength: z.ZodNumber;
                        maxLength: z.ZodNumber;
                    }, "strip", z.ZodTypeAny, {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    }, {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"regex">;
                        pattern: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"email">;
                    }, "strip", z.ZodTypeAny, {
                        type: "email";
                        errorMsg?: string | undefined;
                    }, {
                        type: "email";
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"ipv4">;
                    }, "strip", z.ZodTypeAny, {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    }, {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"url">;
                    }, "strip", z.ZodTypeAny, {
                        type: "url";
                        errorMsg?: string | undefined;
                    }, {
                        type: "url";
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"date">;
                    }, "strip", z.ZodTypeAny, {
                        type: "date";
                        errorMsg?: string | undefined;
                    }, {
                        type: "date";
                        errorMsg?: string | undefined;
                    }>]>, "many">>;
                    defaultValue: z.ZodOptional<z.ZodString>;
                    options: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
                        display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                    }, {
                        rowsMin: z.ZodOptional<z.ZodNumber>;
                        rowsMax: z.ZodOptional<z.ZodNumber>;
                    }>, "strip", z.ZodTypeAny, {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    }, {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    }>>;
                    modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                        mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                        fieldsToModify: z.ZodArray<z.ZodObject<{
                            fieldId: z.ZodString;
                            display: z.ZodOptional<z.ZodBoolean>;
                            value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                            disabled: z.ZodOptional<z.ZodBoolean>;
                            required: z.ZodOptional<z.ZodBoolean>;
                            help: z.ZodOptional<z.ZodString>;
                            label: z.ZodOptional<z.ZodString>;
                            markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                                markdownType: z.ZodLiteral<"text">;
                                text: z.ZodString;
                                color: z.ZodOptional<z.ZodString>;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"hybrid">;
                                text: z.ZodString;
                                token: z.ZodString;
                                linkText: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"link">;
                                text: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodOptional<z.ZodUndefined>;
                                text: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                text: string;
                                markdownType?: undefined;
                            }, {
                                text: string;
                                markdownType?: undefined;
                            }>]>>;
                        }, "strip", z.ZodTypeAny, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }>, "many">;
                    }, "strip", z.ZodTypeAny, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }>, "many">>;
                }>, "strip", z.ZodTypeAny, {
                    type: "textarea";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }, {
                    type: "textarea";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }>, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                    type: z.ZodString;
                    field: z.ZodString;
                    label: z.ZodString;
                    help: z.ZodOptional<z.ZodString>;
                    tooltip: z.ZodOptional<z.ZodString>;
                }, {
                    required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }>, {
                    type: z.ZodLiteral<"singleSelect">;
                    validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"number">;
                        range: z.ZodArray<z.ZodNumber, "many">;
                        isInteger: z.ZodOptional<z.ZodBoolean>;
                    }, "strip", z.ZodTypeAny, {
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    }, {
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"string">;
                        minLength: z.ZodNumber;
                        maxLength: z.ZodNumber;
                    }, "strip", z.ZodTypeAny, {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    }, {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"regex">;
                        pattern: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"email">;
                    }, "strip", z.ZodTypeAny, {
                        type: "email";
                        errorMsg?: string | undefined;
                    }, {
                        type: "email";
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"ipv4">;
                    }, "strip", z.ZodTypeAny, {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    }, {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"url">;
                    }, "strip", z.ZodTypeAny, {
                        type: "url";
                        errorMsg?: string | undefined;
                    }, {
                        type: "url";
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"date">;
                    }, "strip", z.ZodTypeAny, {
                        type: "date";
                        errorMsg?: string | undefined;
                    }, {
                        type: "date";
                        errorMsg?: string | undefined;
                    }>]>, "many">>;
                    defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
                    options: z.ZodObject<z.objectUtil.extendShape<{
                        display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                    }, {
                        disableSearch: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        createSearchChoice: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        referenceName: z.ZodOptional<z.ZodString>;
                        endpointUrl: z.ZodOptional<z.ZodString>;
                        allowList: z.ZodOptional<z.ZodString>;
                        denyList: z.ZodOptional<z.ZodString>;
                        labelField: z.ZodOptional<z.ZodString>;
                        valueField: z.ZodOptional<z.ZodString>;
                        autoCompleteFields: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                            value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                            label: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            value: string | number | boolean;
                            label: string;
                        }, {
                            value: string | number | boolean;
                            label: string;
                        }>, z.ZodObject<{
                            label: z.ZodString;
                            children: z.ZodArray<z.ZodObject<{
                                value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                                label: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                value: string | number | boolean;
                                label: string;
                            }, {
                                value: string | number | boolean;
                                label: string;
                            }>, "many">;
                        }, "strip", z.ZodTypeAny, {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        }, {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        }>]>, "many">>;
                        dependencies: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                        items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                            label: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            value: string | number | boolean;
                            label: string;
                        }, {
                            value: string | number | boolean;
                            label: string;
                        }>, "many">>;
                    }>, "strip", z.ZodTypeAny, {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    }, {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    }>;
                    modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                        mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                        fieldsToModify: z.ZodArray<z.ZodObject<{
                            fieldId: z.ZodString;
                            display: z.ZodOptional<z.ZodBoolean>;
                            value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                            disabled: z.ZodOptional<z.ZodBoolean>;
                            required: z.ZodOptional<z.ZodBoolean>;
                            help: z.ZodOptional<z.ZodString>;
                            label: z.ZodOptional<z.ZodString>;
                            markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                                markdownType: z.ZodLiteral<"text">;
                                text: z.ZodString;
                                color: z.ZodOptional<z.ZodString>;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"hybrid">;
                                text: z.ZodString;
                                token: z.ZodString;
                                linkText: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"link">;
                                text: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodOptional<z.ZodUndefined>;
                                text: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                text: string;
                                markdownType?: undefined;
                            }, {
                                text: string;
                                markdownType?: undefined;
                            }>]>>;
                        }, "strip", z.ZodTypeAny, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }>, "many">;
                    }, "strip", z.ZodTypeAny, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }>, "many">>;
                }>, "strip", z.ZodTypeAny, {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    };
                    type: "singleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }, {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    };
                    type: "singleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }>, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                    type: z.ZodString;
                    field: z.ZodString;
                    label: z.ZodString;
                    help: z.ZodOptional<z.ZodString>;
                    tooltip: z.ZodOptional<z.ZodString>;
                }, {
                    required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }>, {
                    type: z.ZodLiteral<"multipleSelect">;
                    validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"number">;
                        range: z.ZodArray<z.ZodNumber, "many">;
                        isInteger: z.ZodOptional<z.ZodBoolean>;
                    }, "strip", z.ZodTypeAny, {
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    }, {
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"string">;
                        minLength: z.ZodNumber;
                        maxLength: z.ZodNumber;
                    }, "strip", z.ZodTypeAny, {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    }, {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"regex">;
                        pattern: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"email">;
                    }, "strip", z.ZodTypeAny, {
                        type: "email";
                        errorMsg?: string | undefined;
                    }, {
                        type: "email";
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"ipv4">;
                    }, "strip", z.ZodTypeAny, {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    }, {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"url">;
                    }, "strip", z.ZodTypeAny, {
                        type: "url";
                        errorMsg?: string | undefined;
                    }, {
                        type: "url";
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"date">;
                    }, "strip", z.ZodTypeAny, {
                        type: "date";
                        errorMsg?: string | undefined;
                    }, {
                        type: "date";
                        errorMsg?: string | undefined;
                    }>]>, "many">>;
                    defaultValue: z.ZodOptional<z.ZodString>;
                    options: z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                        display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                    }, {
                        disableSearch: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        createSearchChoice: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        referenceName: z.ZodOptional<z.ZodString>;
                        endpointUrl: z.ZodOptional<z.ZodString>;
                        allowList: z.ZodOptional<z.ZodString>;
                        denyList: z.ZodOptional<z.ZodString>;
                        labelField: z.ZodOptional<z.ZodString>;
                        valueField: z.ZodOptional<z.ZodString>;
                        autoCompleteFields: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                            value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                            label: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            value: string | number | boolean;
                            label: string;
                        }, {
                            value: string | number | boolean;
                            label: string;
                        }>, z.ZodObject<{
                            label: z.ZodString;
                            children: z.ZodArray<z.ZodObject<{
                                value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                                label: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                value: string | number | boolean;
                                label: string;
                            }, {
                                value: string | number | boolean;
                                label: string;
                            }>, "many">;
                        }, "strip", z.ZodTypeAny, {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        }, {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        }>]>, "many">>;
                        dependencies: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                        items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                            label: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            value: string | number | boolean;
                            label: string;
                        }, {
                            value: string | number | boolean;
                            label: string;
                        }>, "many">>;
                    }>, {
                        delimiter: z.ZodOptional<z.ZodString>;
                    }>, "strip", z.ZodTypeAny, {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    }, {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    }>;
                    modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                        mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                        fieldsToModify: z.ZodArray<z.ZodObject<{
                            fieldId: z.ZodString;
                            display: z.ZodOptional<z.ZodBoolean>;
                            value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                            disabled: z.ZodOptional<z.ZodBoolean>;
                            required: z.ZodOptional<z.ZodBoolean>;
                            help: z.ZodOptional<z.ZodString>;
                            label: z.ZodOptional<z.ZodString>;
                            markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                                markdownType: z.ZodLiteral<"text">;
                                text: z.ZodString;
                                color: z.ZodOptional<z.ZodString>;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"hybrid">;
                                text: z.ZodString;
                                token: z.ZodString;
                                linkText: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"link">;
                                text: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodOptional<z.ZodUndefined>;
                                text: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                text: string;
                                markdownType?: undefined;
                            }, {
                                text: string;
                                markdownType?: undefined;
                            }>]>>;
                        }, "strip", z.ZodTypeAny, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }>, "many">;
                    }, "strip", z.ZodTypeAny, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }>, "many">>;
                }>, "strip", z.ZodTypeAny, {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    };
                    type: "multipleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }, {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    };
                    type: "multipleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }>, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                    type: z.ZodString;
                    field: z.ZodString;
                    label: z.ZodString;
                    help: z.ZodOptional<z.ZodString>;
                    tooltip: z.ZodOptional<z.ZodString>;
                }, {
                    required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }>, {
                    type: z.ZodLiteral<"checkbox">;
                    defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodBoolean]>>;
                    options: z.ZodOptional<z.ZodObject<{
                        display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                    }, "strip", z.ZodTypeAny, {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    }, {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    }>>;
                    modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                        mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                        fieldsToModify: z.ZodArray<z.ZodObject<{
                            fieldId: z.ZodString;
                            display: z.ZodOptional<z.ZodBoolean>;
                            value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                            disabled: z.ZodOptional<z.ZodBoolean>;
                            required: z.ZodOptional<z.ZodBoolean>;
                            help: z.ZodOptional<z.ZodString>;
                            label: z.ZodOptional<z.ZodString>;
                            markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                                markdownType: z.ZodLiteral<"text">;
                                text: z.ZodString;
                                color: z.ZodOptional<z.ZodString>;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"hybrid">;
                                text: z.ZodString;
                                token: z.ZodString;
                                linkText: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"link">;
                                text: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodOptional<z.ZodUndefined>;
                                text: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                text: string;
                                markdownType?: undefined;
                            }, {
                                text: string;
                                markdownType?: undefined;
                            }>]>>;
                        }, "strip", z.ZodTypeAny, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }>, "many">;
                    }, "strip", z.ZodTypeAny, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }>, "many">>;
                }>, "strip", z.ZodTypeAny, {
                    type: "checkbox";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }, {
                    type: "checkbox";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }>, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                    type: z.ZodString;
                    field: z.ZodString;
                    label: z.ZodString;
                    help: z.ZodOptional<z.ZodString>;
                    tooltip: z.ZodOptional<z.ZodString>;
                }, {
                    required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }>, {
                    type: z.ZodLiteral<"checkboxGroup">;
                    validators: z.ZodOptional<z.ZodTuple<[z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"regex">;
                        pattern: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }>], null>>;
                    defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodBoolean]>>;
                    options: z.ZodObject<z.objectUtil.extendShape<{
                        display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                    }, {
                        groups: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            label: z.ZodString;
                            fields: z.ZodArray<z.ZodString, "many">;
                            options: z.ZodOptional<z.ZodObject<{
                                isExpandable: z.ZodOptional<z.ZodBoolean>;
                                expand: z.ZodOptional<z.ZodBoolean>;
                            }, "strip", z.ZodTypeAny, {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            }, {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            }>>;
                        }, "strip", z.ZodTypeAny, {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }, {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }>, "many">>;
                        rows: z.ZodArray<z.ZodObject<{
                            field: z.ZodString;
                            checkbox: z.ZodOptional<z.ZodObject<{
                                label: z.ZodOptional<z.ZodString>;
                                defaultValue: z.ZodOptional<z.ZodBoolean>;
                            }, "strip", z.ZodTypeAny, {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            }, {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            }>>;
                            input: z.ZodOptional<z.ZodObject<{
                                defaultValue: z.ZodOptional<z.ZodNumber>;
                                validators: z.ZodOptional<z.ZodTuple<[z.ZodObject<{
                                    errorMsg: z.ZodOptional<z.ZodString>;
                                    type: z.ZodLiteral<"number">;
                                    range: z.ZodArray<z.ZodNumber, "many">;
                                    isInteger: z.ZodOptional<z.ZodBoolean>;
                                }, "strip", z.ZodTypeAny, {
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }, {
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }>], null>>;
                                required: z.ZodOptional<z.ZodBoolean>;
                            }, "strip", z.ZodTypeAny, {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            }, {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            }>>;
                        }, "strip", z.ZodTypeAny, {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }, {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }>, "many">;
                    }>, "strip", z.ZodTypeAny, {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    }, {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    }>;
                }>, "strip", z.ZodTypeAny, {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxGroup";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                }, {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxGroup";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                }>, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                    type: z.ZodString;
                    field: z.ZodString;
                    label: z.ZodString;
                    help: z.ZodOptional<z.ZodString>;
                    tooltip: z.ZodOptional<z.ZodString>;
                }, {
                    required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }>, {
                    type: z.ZodLiteral<"checkboxTree">;
                    validators: z.ZodOptional<z.ZodTuple<[z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"regex">;
                        pattern: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }>], null>>;
                    defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodBoolean]>>;
                    options: z.ZodObject<z.objectUtil.extendShape<{
                        display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                    }, {
                        groups: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            label: z.ZodString;
                            fields: z.ZodArray<z.ZodString, "many">;
                            options: z.ZodOptional<z.ZodObject<{
                                isExpandable: z.ZodOptional<z.ZodBoolean>;
                                expand: z.ZodOptional<z.ZodBoolean>;
                            }, "strip", z.ZodTypeAny, {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            }, {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            }>>;
                        }, "strip", z.ZodTypeAny, {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }, {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }>, "many">>;
                        rows: z.ZodArray<z.ZodObject<{
                            field: z.ZodString;
                            checkbox: z.ZodOptional<z.ZodObject<{
                                label: z.ZodOptional<z.ZodString>;
                                defaultValue: z.ZodOptional<z.ZodBoolean>;
                            }, "strip", z.ZodTypeAny, {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            }, {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            }>>;
                        }, "strip", z.ZodTypeAny, {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }, {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }>, "many">;
                    }>, "strip", z.ZodTypeAny, {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    }, {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    }>;
                }>, "strip", z.ZodTypeAny, {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxTree";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                }, {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxTree";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                }>, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                    type: z.ZodString;
                    field: z.ZodString;
                    label: z.ZodString;
                    help: z.ZodOptional<z.ZodString>;
                    tooltip: z.ZodOptional<z.ZodString>;
                }, {
                    required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }>, {
                    type: z.ZodLiteral<"radio">;
                    defaultValue: z.ZodOptional<z.ZodString>;
                    options: z.ZodObject<z.objectUtil.extendShape<{
                        display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                    }, {
                        items: z.ZodArray<z.ZodObject<{
                            value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                            label: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            value: string | number | boolean;
                            label: string;
                        }, {
                            value: string | number | boolean;
                            label: string;
                        }>, "many">;
                    }>, "strip", z.ZodTypeAny, {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    }, {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    }>;
                    modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                        mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                        fieldsToModify: z.ZodArray<z.ZodObject<{
                            fieldId: z.ZodString;
                            display: z.ZodOptional<z.ZodBoolean>;
                            value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                            disabled: z.ZodOptional<z.ZodBoolean>;
                            required: z.ZodOptional<z.ZodBoolean>;
                            help: z.ZodOptional<z.ZodString>;
                            label: z.ZodOptional<z.ZodString>;
                            markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                                markdownType: z.ZodLiteral<"text">;
                                text: z.ZodString;
                                color: z.ZodOptional<z.ZodString>;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"hybrid">;
                                text: z.ZodString;
                                token: z.ZodString;
                                linkText: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"link">;
                                text: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodOptional<z.ZodUndefined>;
                                text: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                text: string;
                                markdownType?: undefined;
                            }, {
                                text: string;
                                markdownType?: undefined;
                            }>]>>;
                        }, "strip", z.ZodTypeAny, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }>, "many">;
                    }, "strip", z.ZodTypeAny, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }>, "many">>;
                }>, "strip", z.ZodTypeAny, {
                    options: {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "radio";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }, {
                    options: {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "radio";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }>, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                    type: z.ZodString;
                    field: z.ZodString;
                    label: z.ZodString;
                    help: z.ZodOptional<z.ZodString>;
                    tooltip: z.ZodOptional<z.ZodString>;
                }, {
                    required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }>, {
                    type: z.ZodLiteral<"file">;
                    defaultValue: z.ZodOptional<z.ZodString>;
                    validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"string">;
                        minLength: z.ZodNumber;
                        maxLength: z.ZodNumber;
                    }, "strip", z.ZodTypeAny, {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    }, {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"regex">;
                        pattern: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }>]>, "many">>;
                    options: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
                        display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                    }, {
                        maxFileSize: z.ZodOptional<z.ZodNumber>;
                        fileSupportMessage: z.ZodOptional<z.ZodString>;
                        supportedFileTypes: z.ZodArray<z.ZodString, "many">;
                        useBase64Encoding: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    }>, "strip", z.ZodTypeAny, {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    }, {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    }>>;
                    modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                        mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                        fieldsToModify: z.ZodArray<z.ZodObject<{
                            fieldId: z.ZodString;
                            display: z.ZodOptional<z.ZodBoolean>;
                            value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                            disabled: z.ZodOptional<z.ZodBoolean>;
                            required: z.ZodOptional<z.ZodBoolean>;
                            help: z.ZodOptional<z.ZodString>;
                            label: z.ZodOptional<z.ZodString>;
                            markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                                markdownType: z.ZodLiteral<"text">;
                                text: z.ZodString;
                                color: z.ZodOptional<z.ZodString>;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }, {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"hybrid">;
                                text: z.ZodString;
                                token: z.ZodString;
                                linkText: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }, {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodLiteral<"link">;
                                text: z.ZodString;
                                link: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }, {
                                markdownType: "link";
                                text: string;
                                link: string;
                            }>, z.ZodObject<{
                                markdownType: z.ZodOptional<z.ZodUndefined>;
                                text: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                text: string;
                                markdownType?: undefined;
                            }, {
                                text: string;
                                markdownType?: undefined;
                            }>]>>;
                        }, "strip", z.ZodTypeAny, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }, {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }>, "many">;
                    }, "strip", z.ZodTypeAny, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }, {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }>, "many">>;
                }>, "strip", z.ZodTypeAny, {
                    type: "file";
                    label: string;
                    field: string;
                    options?: {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }, {
                    type: "file";
                    label: string;
                    field: string;
                    options?: {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                }>, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                    type: z.ZodString;
                    field: z.ZodString;
                    label: z.ZodString;
                    help: z.ZodOptional<z.ZodString>;
                    tooltip: z.ZodOptional<z.ZodString>;
                }, {
                    required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }>, {
                    type: z.ZodLiteral<"oauth">;
                    defaultValue: z.ZodOptional<z.ZodString>;
                    validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"string">;
                        minLength: z.ZodNumber;
                        maxLength: z.ZodNumber;
                    }, "strip", z.ZodTypeAny, {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    }, {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    }>, z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"regex">;
                        pattern: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }, {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }>]>, "many">>;
                    options: z.ZodObject<z.objectUtil.extendShape<Omit<{
                        display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                    }, "requiredWhenVisible">, {
                        auth_type: z.ZodArray<z.ZodUnion<[z.ZodLiteral<"basic">, z.ZodLiteral<"oauth">]>, "many">;
                        basic: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            oauth_field: z.ZodString;
                            label: z.ZodString;
                            field: z.ZodString;
                            type: z.ZodOptional<z.ZodDefault<z.ZodLiteral<"text">>>;
                            help: z.ZodString;
                            encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
                            options: z.ZodOptional<z.ZodObject<{
                                display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                                disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                                enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                                requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                                hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                            }, "strip", z.ZodTypeAny, {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            }, {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            }>>;
                            modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                                mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                                fieldsToModify: z.ZodArray<z.ZodObject<{
                                    fieldId: z.ZodString;
                                    display: z.ZodOptional<z.ZodBoolean>;
                                    value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                                    disabled: z.ZodOptional<z.ZodBoolean>;
                                    required: z.ZodOptional<z.ZodBoolean>;
                                    help: z.ZodOptional<z.ZodString>;
                                    label: z.ZodOptional<z.ZodString>;
                                    markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                                        markdownType: z.ZodLiteral<"text">;
                                        text: z.ZodString;
                                        color: z.ZodOptional<z.ZodString>;
                                    }, "strip", z.ZodTypeAny, {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    }, {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    }>, z.ZodObject<{
                                        markdownType: z.ZodLiteral<"hybrid">;
                                        text: z.ZodString;
                                        token: z.ZodString;
                                        linkText: z.ZodString;
                                        link: z.ZodString;
                                    }, "strip", z.ZodTypeAny, {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    }, {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    }>, z.ZodObject<{
                                        markdownType: z.ZodLiteral<"link">;
                                        text: z.ZodString;
                                        link: z.ZodString;
                                    }, "strip", z.ZodTypeAny, {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    }, {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    }>, z.ZodObject<{
                                        markdownType: z.ZodOptional<z.ZodUndefined>;
                                        text: z.ZodString;
                                    }, "strip", z.ZodTypeAny, {
                                        text: string;
                                        markdownType?: undefined;
                                    }, {
                                        text: string;
                                        markdownType?: undefined;
                                    }>]>>;
                                }, "strip", z.ZodTypeAny, {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }, {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }>, "many">;
                            }, "strip", z.ZodTypeAny, {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }, {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }>, "many">>;
                            validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"number">;
                                range: z.ZodArray<z.ZodNumber, "many">;
                                isInteger: z.ZodOptional<z.ZodBoolean>;
                            }, "strip", z.ZodTypeAny, {
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }, {
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }>, z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"string">;
                                minLength: z.ZodNumber;
                                maxLength: z.ZodNumber;
                            }, "strip", z.ZodTypeAny, {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            }, {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            }>, z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"regex">;
                                pattern: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            }, {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            }>, z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"email">;
                            }, "strip", z.ZodTypeAny, {
                                type: "email";
                                errorMsg?: string | undefined;
                            }, {
                                type: "email";
                                errorMsg?: string | undefined;
                            }>, z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"ipv4">;
                            }, "strip", z.ZodTypeAny, {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            }, {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            }>, z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"url">;
                            }, "strip", z.ZodTypeAny, {
                                type: "url";
                                errorMsg?: string | undefined;
                            }, {
                                type: "url";
                                errorMsg?: string | undefined;
                            }>, z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"date">;
                            }, "strip", z.ZodTypeAny, {
                                type: "date";
                                errorMsg?: string | undefined;
                            }, {
                                type: "date";
                                errorMsg?: string | undefined;
                            }>]>, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }, {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }>, "many">>;
                        oauth: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            oauth_field: z.ZodString;
                            label: z.ZodString;
                            field: z.ZodString;
                            type: z.ZodOptional<z.ZodDefault<z.ZodLiteral<"text">>>;
                            help: z.ZodString;
                            encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
                            options: z.ZodOptional<z.ZodObject<{
                                display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                                disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                                enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                                requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                                hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                            }, "strip", z.ZodTypeAny, {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            }, {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            }>>;
                            modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                                mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                                fieldsToModify: z.ZodArray<z.ZodObject<{
                                    fieldId: z.ZodString;
                                    display: z.ZodOptional<z.ZodBoolean>;
                                    value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                                    disabled: z.ZodOptional<z.ZodBoolean>;
                                    required: z.ZodOptional<z.ZodBoolean>;
                                    help: z.ZodOptional<z.ZodString>;
                                    label: z.ZodOptional<z.ZodString>;
                                    markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                                        markdownType: z.ZodLiteral<"text">;
                                        text: z.ZodString;
                                        color: z.ZodOptional<z.ZodString>;
                                    }, "strip", z.ZodTypeAny, {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    }, {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    }>, z.ZodObject<{
                                        markdownType: z.ZodLiteral<"hybrid">;
                                        text: z.ZodString;
                                        token: z.ZodString;
                                        linkText: z.ZodString;
                                        link: z.ZodString;
                                    }, "strip", z.ZodTypeAny, {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    }, {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    }>, z.ZodObject<{
                                        markdownType: z.ZodLiteral<"link">;
                                        text: z.ZodString;
                                        link: z.ZodString;
                                    }, "strip", z.ZodTypeAny, {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    }, {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    }>, z.ZodObject<{
                                        markdownType: z.ZodOptional<z.ZodUndefined>;
                                        text: z.ZodString;
                                    }, "strip", z.ZodTypeAny, {
                                        text: string;
                                        markdownType?: undefined;
                                    }, {
                                        text: string;
                                        markdownType?: undefined;
                                    }>]>>;
                                }, "strip", z.ZodTypeAny, {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }, {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }>, "many">;
                            }, "strip", z.ZodTypeAny, {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }, {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }>, "many">>;
                            validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"number">;
                                range: z.ZodArray<z.ZodNumber, "many">;
                                isInteger: z.ZodOptional<z.ZodBoolean>;
                            }, "strip", z.ZodTypeAny, {
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }, {
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }>, z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"string">;
                                minLength: z.ZodNumber;
                                maxLength: z.ZodNumber;
                            }, "strip", z.ZodTypeAny, {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            }, {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            }>, z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"regex">;
                                pattern: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            }, {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            }>, z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"email">;
                            }, "strip", z.ZodTypeAny, {
                                type: "email";
                                errorMsg?: string | undefined;
                            }, {
                                type: "email";
                                errorMsg?: string | undefined;
                            }>, z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"ipv4">;
                            }, "strip", z.ZodTypeAny, {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            }, {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            }>, z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"url">;
                            }, "strip", z.ZodTypeAny, {
                                type: "url";
                                errorMsg?: string | undefined;
                            }, {
                                type: "url";
                                errorMsg?: string | undefined;
                            }>, z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"date">;
                            }, "strip", z.ZodTypeAny, {
                                type: "date";
                                errorMsg?: string | undefined;
                            }, {
                                type: "date";
                                errorMsg?: string | undefined;
                            }>]>, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }, {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }>, "many">>;
                        auth_label: z.ZodOptional<z.ZodString>;
                        oauth_popup_width: z.ZodOptional<z.ZodNumber>;
                        oauth_popup_height: z.ZodOptional<z.ZodNumber>;
                        oauth_timeout: z.ZodOptional<z.ZodNumber>;
                        auth_code_endpoint: z.ZodOptional<z.ZodString>;
                        access_token_endpoint: z.ZodOptional<z.ZodString>;
                        oauth_state_enabled: z.ZodOptional<z.ZodBoolean>;
                        auth_endpoint_token_access_type: z.ZodOptional<z.ZodString>;
                    }>, "strip", z.ZodTypeAny, {
                        auth_type: ("oauth" | "basic")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    }, {
                        auth_type: ("oauth" | "basic")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    }>;
                }>, "strip", z.ZodTypeAny, {
                    options: {
                        auth_type: ("oauth" | "basic")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    };
                    type: "oauth";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                }, {
                    options: {
                        auth_type: ("oauth" | "basic")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    };
                    type: "oauth";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                }>, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                    type: z.ZodString;
                    field: z.ZodString;
                    label: z.ZodString;
                    help: z.ZodOptional<z.ZodString>;
                    tooltip: z.ZodOptional<z.ZodString>;
                }, {
                    required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }>, {
                    type: z.ZodLiteral<"custom">;
                    options: z.ZodObject<{
                        type: z.ZodLiteral<"external">;
                        src: z.ZodString;
                        hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                    }, "strip", z.ZodTypeAny, {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    }, {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    }>;
                }>, "strip", z.ZodTypeAny, {
                    options: {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "custom";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                }, {
                    options: {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "custom";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                }>]>, "many">;
                options: z.ZodOptional<z.ZodObject<{
                    saveValidator: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    saveValidator?: string | undefined;
                }, {
                    saveValidator?: string | undefined;
                }>>;
                groups: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    options: z.ZodOptional<z.ZodObject<{
                        isExpandable: z.ZodOptional<z.ZodBoolean>;
                        expand: z.ZodOptional<z.ZodBoolean>;
                    }, "strip", z.ZodTypeAny, {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    }, {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    }>>;
                    label: z.ZodString;
                    fields: z.ZodArray<z.ZodString, "many">;
                }, "strip", z.ZodTypeAny, {
                    label: string;
                    fields: string[];
                    options?: {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    } | undefined;
                }, {
                    label: string;
                    fields: string[];
                    options?: {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    } | undefined;
                }>, "many">>;
                style: z.ZodOptional<z.ZodEnum<["page", "dialog"]>>;
                hook: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
                conf: z.ZodOptional<z.ZodString>;
                restHandlerName: z.ZodOptional<z.ZodString>;
                restHandlerModule: z.ZodOptional<z.ZodString>;
                restHandlerClass: z.ZodOptional<z.ZodString>;
                warning: z.ZodOptional<z.ZodObject<{
                    create: z.ZodOptional<z.ZodObject<{
                        message: z.ZodString;
                        alwaysDisplay: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    }, "strip", z.ZodTypeAny, {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    }, {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    }>>;
                    edit: z.ZodOptional<z.ZodObject<{
                        message: z.ZodString;
                        alwaysDisplay: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    }, "strip", z.ZodTypeAny, {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    }, {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    }>>;
                    config: z.ZodOptional<z.ZodObject<{
                        message: z.ZodString;
                        alwaysDisplay: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    }, "strip", z.ZodTypeAny, {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    }, {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    }>>;
                    clone: z.ZodOptional<z.ZodObject<{
                        message: z.ZodString;
                        alwaysDisplay: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    }, "strip", z.ZodTypeAny, {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    }, {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    }>>;
                }, "strip", z.ZodTypeAny, {
                    clone?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    create?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    edit?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    config?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                }, {
                    clone?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    create?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    edit?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    config?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                }>>;
                inputHelperModule: z.ZodOptional<z.ZodString>;
                disableNewInput: z.ZodOptional<z.ZodBoolean>;
                hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
            }, "strict", z.ZodTypeAny, {
                name: string;
                entity: ({
                    options: {
                        text: string;
                        link: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "helpLink";
                    field: string;
                    label?: string | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: false | undefined;
                } | {
                    type: "text";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "textarea";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    };
                    type: "singleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    };
                    type: "multipleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "checkbox";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxGroup";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxTree";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "radio";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "file";
                    label: string;
                    field: string;
                    options?: {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        auth_type: ("oauth" | "basic")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    };
                    type: "oauth";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                } | {
                    options: {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "custom";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                })[];
                title: string;
                options?: {
                    saveValidator?: string | undefined;
                } | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                groups?: {
                    label: string;
                    fields: string[];
                    options?: {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    } | undefined;
                }[] | undefined;
                style?: "page" | "dialog" | undefined;
                hook?: Record<string, any> | undefined;
                conf?: string | undefined;
                restHandlerName?: string | undefined;
                restHandlerModule?: string | undefined;
                restHandlerClass?: string | undefined;
                warning?: {
                    clone?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    create?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    edit?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    config?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                } | undefined;
                subTitle?: string | undefined;
                inputHelperModule?: string | undefined;
                disableNewInput?: boolean | undefined;
            }, {
                name: string;
                entity: ({
                    options: {
                        text: string;
                        link: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "helpLink";
                    field: string;
                    label?: string | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: false | undefined;
                } | {
                    type: "text";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "textarea";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    };
                    type: "singleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    };
                    type: "multipleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "checkbox";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxGroup";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxTree";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "radio";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "file";
                    label: string;
                    field: string;
                    options?: {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        auth_type: ("oauth" | "basic")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    };
                    type: "oauth";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                } | {
                    options: {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "custom";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                })[];
                title: string;
                options?: {
                    saveValidator?: string | undefined;
                } | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                groups?: {
                    label: string;
                    fields: string[];
                    options?: {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    } | undefined;
                }[] | undefined;
                style?: "page" | "dialog" | undefined;
                hook?: Record<string, any> | undefined;
                conf?: string | undefined;
                restHandlerName?: string | undefined;
                restHandlerModule?: string | undefined;
                restHandlerClass?: string | undefined;
                warning?: {
                    clone?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    create?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    edit?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    config?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                } | undefined;
                subTitle?: string | undefined;
                inputHelperModule?: string | undefined;
                disableNewInput?: boolean | undefined;
            }>, "many">;
            hideFieldId: z.ZodOptional<z.ZodString>;
            readonlyFieldId: z.ZodOptional<z.ZodString>;
            useInputToggleConfirmation: z.ZodOptional<z.ZodBoolean>;
        }, "strict", z.ZodTypeAny, {
            title: string;
            table: {
                header: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                    customCell?: Record<string, any> | undefined;
                }[];
                actions: ("clone" | "delete" | "edit" | "search")[];
                moreInfo?: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                }[] | undefined;
                customRow?: Record<string, any> | undefined;
            };
            services: {
                name: string;
                entity: ({
                    options: {
                        text: string;
                        link: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "helpLink";
                    field: string;
                    label?: string | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: false | undefined;
                } | {
                    type: "text";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "textarea";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    };
                    type: "singleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    };
                    type: "multipleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "checkbox";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxGroup";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxTree";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "radio";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "file";
                    label: string;
                    field: string;
                    options?: {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        auth_type: ("oauth" | "basic")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    };
                    type: "oauth";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                } | {
                    options: {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "custom";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                })[];
                title: string;
                options?: {
                    saveValidator?: string | undefined;
                } | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                groups?: {
                    label: string;
                    fields: string[];
                    options?: {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    } | undefined;
                }[] | undefined;
                style?: "page" | "dialog" | undefined;
                hook?: Record<string, any> | undefined;
                conf?: string | undefined;
                restHandlerName?: string | undefined;
                restHandlerModule?: string | undefined;
                restHandlerClass?: string | undefined;
                warning?: {
                    clone?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    create?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    edit?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    config?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                } | undefined;
                subTitle?: string | undefined;
                inputHelperModule?: string | undefined;
                disableNewInput?: boolean | undefined;
            }[];
            description?: string | undefined;
            useInputToggleConfirmation?: boolean | undefined;
            subDescription?: {
                text: string;
                links?: {
                    linkText: string;
                    link: string;
                    slug: string;
                }[] | undefined;
            } | undefined;
            menu?: {
                type: "external";
                src: string;
            } | undefined;
            groupsMenu?: {
                groupName: string;
                groupTitle: string;
                groupServices?: string[] | undefined;
            }[] | undefined;
            hideFieldId?: string | undefined;
            readonlyFieldId?: string | undefined;
        }, {
            title: string;
            table: {
                header: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                    customCell?: Record<string, any> | undefined;
                }[];
                actions: ("clone" | "delete" | "edit" | "search")[];
                moreInfo?: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                }[] | undefined;
                customRow?: Record<string, any> | undefined;
            };
            services: {
                name: string;
                entity: ({
                    options: {
                        text: string;
                        link: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "helpLink";
                    field: string;
                    label?: string | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: false | undefined;
                } | {
                    type: "text";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "textarea";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    };
                    type: "singleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    };
                    type: "multipleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "checkbox";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxGroup";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxTree";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "radio";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "file";
                    label: string;
                    field: string;
                    options?: {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        auth_type: ("oauth" | "basic")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    };
                    type: "oauth";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                } | {
                    options: {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "custom";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                })[];
                title: string;
                options?: {
                    saveValidator?: string | undefined;
                } | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                groups?: {
                    label: string;
                    fields: string[];
                    options?: {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    } | undefined;
                }[] | undefined;
                style?: "page" | "dialog" | undefined;
                hook?: Record<string, any> | undefined;
                conf?: string | undefined;
                restHandlerName?: string | undefined;
                restHandlerModule?: string | undefined;
                restHandlerClass?: string | undefined;
                warning?: {
                    clone?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    create?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    edit?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    config?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                } | undefined;
                subTitle?: string | undefined;
                inputHelperModule?: string | undefined;
                disableNewInput?: boolean | undefined;
            }[];
            description?: string | undefined;
            useInputToggleConfirmation?: boolean | undefined;
            subDescription?: {
                text: string;
                links?: {
                    linkText: string;
                    link: string;
                    slug: string;
                }[] | undefined;
            } | undefined;
            menu?: {
                type: "external";
                src: string;
            } | undefined;
            groupsMenu?: {
                groupName: string;
                groupTitle: string;
                groupServices?: string[] | undefined;
            }[] | undefined;
            hideFieldId?: string | undefined;
            readonlyFieldId?: string | undefined;
        }>]>>;
        dashboard: z.ZodOptional<z.ZodObject<{
            panels: z.ZodArray<z.ZodObject<{
                name: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                name: string;
            }, {
                name: string;
            }>, "many">;
            troubleshooting_url: z.ZodOptional<z.ZodString>;
            settings: z.ZodOptional<z.ZodObject<{
                custom_tab_name: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                custom_tab_name?: string | undefined;
            }, {
                custom_tab_name?: string | undefined;
            }>>;
        }, "strip", z.ZodTypeAny, {
            panels: {
                name: string;
            }[];
            troubleshooting_url?: string | undefined;
            settings?: {
                custom_tab_name?: string | undefined;
            } | undefined;
        }, {
            panels: {
                name: string;
            }[];
            troubleshooting_url?: string | undefined;
            settings?: {
                custom_tab_name?: string | undefined;
            } | undefined;
        }>>;
    }, "strip", z.ZodTypeAny, {
        configuration: {
            title: string;
            tabs: {
                name: string;
                title: string;
                options?: {
                    saveValidator?: string | undefined;
                } | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                groups?: {
                    label: string;
                    fields: string[];
                    options?: {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    } | undefined;
                }[] | undefined;
                entity?: ({
                    options: {
                        text: string;
                        link: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "helpLink";
                    field: string;
                    label?: string | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: false | undefined;
                } | {
                    type: "text";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "textarea";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    };
                    type: "singleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    };
                    type: "multipleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "checkbox";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxGroup";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxTree";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "radio";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "file";
                    label: string;
                    field: string;
                    options?: {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        auth_type: ("oauth" | "basic")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    };
                    type: "oauth";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                } | {
                    options: {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "custom";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                })[] | undefined;
                table?: {
                    header: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                        customCell?: Record<string, any> | undefined;
                    }[];
                    actions: ("clone" | "delete" | "edit")[];
                    moreInfo?: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                    }[] | undefined;
                    customRow?: Record<string, any> | undefined;
                } | undefined;
                style?: "page" | "dialog" | undefined;
                hook?: Record<string, any> | undefined;
                conf?: string | undefined;
                restHandlerName?: string | undefined;
                restHandlerModule?: string | undefined;
                restHandlerClass?: string | undefined;
                customTab?: Record<string, any> | undefined;
                warning?: {
                    clone?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    create?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    edit?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    config?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                } | undefined;
            }[];
            description?: string | undefined;
            subDescription?: {
                text: string;
                links?: {
                    linkText: string;
                    link: string;
                    slug: string;
                }[] | undefined;
            } | undefined;
        };
        inputs?: {
            title: string;
            services: {
                name: string;
                entity: ({
                    options: {
                        text: string;
                        link: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "helpLink";
                    field: string;
                    label?: string | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: false | undefined;
                } | {
                    type: "text";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "textarea";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    };
                    type: "singleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    };
                    type: "multipleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "checkbox";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxGroup";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxTree";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "radio";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "file";
                    label: string;
                    field: string;
                    options?: {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        auth_type: ("oauth" | "basic")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    };
                    type: "oauth";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                } | {
                    options: {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "custom";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                })[];
                title: string;
                table: {
                    header: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                        customCell?: Record<string, any> | undefined;
                    }[];
                    actions: ("clone" | "delete" | "edit" | "search")[];
                    moreInfo?: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                    }[] | undefined;
                    customRow?: Record<string, any> | undefined;
                };
                options?: {
                    saveValidator?: string | undefined;
                } | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                groups?: {
                    label: string;
                    fields: string[];
                    options?: {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    } | undefined;
                }[] | undefined;
                style?: "page" | "dialog" | undefined;
                hook?: Record<string, any> | undefined;
                conf?: string | undefined;
                restHandlerName?: string | undefined;
                restHandlerModule?: string | undefined;
                restHandlerClass?: string | undefined;
                warning?: {
                    clone?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    create?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    edit?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    config?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                } | undefined;
                subTitle?: string | undefined;
                inputHelperModule?: string | undefined;
                disableNewInput?: boolean | undefined;
                description?: string | undefined;
                useInputToggleConfirmation?: boolean | undefined;
            }[];
        } | {
            title: string;
            table: {
                header: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                    customCell?: Record<string, any> | undefined;
                }[];
                actions: ("clone" | "delete" | "edit" | "search")[];
                moreInfo?: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                }[] | undefined;
                customRow?: Record<string, any> | undefined;
            };
            services: {
                name: string;
                entity: ({
                    options: {
                        text: string;
                        link: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "helpLink";
                    field: string;
                    label?: string | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: false | undefined;
                } | {
                    type: "text";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "textarea";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    };
                    type: "singleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    };
                    type: "multipleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "checkbox";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxGroup";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxTree";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "radio";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "file";
                    label: string;
                    field: string;
                    options?: {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        auth_type: ("oauth" | "basic")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    };
                    type: "oauth";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                } | {
                    options: {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "custom";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                })[];
                title: string;
                options?: {
                    saveValidator?: string | undefined;
                } | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                groups?: {
                    label: string;
                    fields: string[];
                    options?: {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    } | undefined;
                }[] | undefined;
                style?: "page" | "dialog" | undefined;
                hook?: Record<string, any> | undefined;
                conf?: string | undefined;
                restHandlerName?: string | undefined;
                restHandlerModule?: string | undefined;
                restHandlerClass?: string | undefined;
                warning?: {
                    clone?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    create?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    edit?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    config?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                } | undefined;
                subTitle?: string | undefined;
                inputHelperModule?: string | undefined;
                disableNewInput?: boolean | undefined;
            }[];
            description?: string | undefined;
            useInputToggleConfirmation?: boolean | undefined;
            subDescription?: {
                text: string;
                links?: {
                    linkText: string;
                    link: string;
                    slug: string;
                }[] | undefined;
            } | undefined;
            menu?: {
                type: "external";
                src: string;
            } | undefined;
            groupsMenu?: {
                groupName: string;
                groupTitle: string;
                groupServices?: string[] | undefined;
            }[] | undefined;
            hideFieldId?: string | undefined;
            readonlyFieldId?: string | undefined;
        } | undefined;
        dashboard?: {
            panels: {
                name: string;
            }[];
            troubleshooting_url?: string | undefined;
            settings?: {
                custom_tab_name?: string | undefined;
            } | undefined;
        } | undefined;
    }, {
        configuration: {
            title: string;
            tabs: {
                name: string;
                title: string;
                options?: {
                    saveValidator?: string | undefined;
                } | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                groups?: {
                    label: string;
                    fields: string[];
                    options?: {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    } | undefined;
                }[] | undefined;
                entity?: ({
                    options: {
                        text: string;
                        link: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "helpLink";
                    field: string;
                    label?: string | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: false | undefined;
                } | {
                    type: "text";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "textarea";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    };
                    type: "singleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    };
                    type: "multipleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "checkbox";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxGroup";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxTree";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "radio";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "file";
                    label: string;
                    field: string;
                    options?: {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        auth_type: ("oauth" | "basic")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    };
                    type: "oauth";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                } | {
                    options: {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "custom";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                })[] | undefined;
                table?: {
                    header: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                        customCell?: Record<string, any> | undefined;
                    }[];
                    actions: ("clone" | "delete" | "edit")[];
                    moreInfo?: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                    }[] | undefined;
                    customRow?: Record<string, any> | undefined;
                } | undefined;
                style?: "page" | "dialog" | undefined;
                hook?: Record<string, any> | undefined;
                conf?: string | undefined;
                restHandlerName?: string | undefined;
                restHandlerModule?: string | undefined;
                restHandlerClass?: string | undefined;
                customTab?: Record<string, any> | undefined;
                warning?: {
                    clone?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    create?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    edit?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    config?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                } | undefined;
            }[];
            description?: string | undefined;
            subDescription?: {
                text: string;
                links?: {
                    linkText: string;
                    link: string;
                    slug: string;
                }[] | undefined;
            } | undefined;
        };
        inputs?: {
            title: string;
            services: {
                name: string;
                entity: ({
                    options: {
                        text: string;
                        link: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "helpLink";
                    field: string;
                    label?: string | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: false | undefined;
                } | {
                    type: "text";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "textarea";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    };
                    type: "singleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    };
                    type: "multipleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "checkbox";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxGroup";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxTree";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "radio";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "file";
                    label: string;
                    field: string;
                    options?: {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        auth_type: ("oauth" | "basic")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    };
                    type: "oauth";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                } | {
                    options: {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "custom";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                })[];
                title: string;
                table: {
                    header: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                        customCell?: Record<string, any> | undefined;
                    }[];
                    actions: ("clone" | "delete" | "edit" | "search")[];
                    moreInfo?: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                    }[] | undefined;
                    customRow?: Record<string, any> | undefined;
                };
                options?: {
                    saveValidator?: string | undefined;
                } | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                groups?: {
                    label: string;
                    fields: string[];
                    options?: {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    } | undefined;
                }[] | undefined;
                style?: "page" | "dialog" | undefined;
                hook?: Record<string, any> | undefined;
                conf?: string | undefined;
                restHandlerName?: string | undefined;
                restHandlerModule?: string | undefined;
                restHandlerClass?: string | undefined;
                warning?: {
                    clone?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    create?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    edit?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    config?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                } | undefined;
                subTitle?: string | undefined;
                inputHelperModule?: string | undefined;
                disableNewInput?: boolean | undefined;
                description?: string | undefined;
                useInputToggleConfirmation?: boolean | undefined;
            }[];
        } | {
            title: string;
            table: {
                header: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                    customCell?: Record<string, any> | undefined;
                }[];
                actions: ("clone" | "delete" | "edit" | "search")[];
                moreInfo?: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                }[] | undefined;
                customRow?: Record<string, any> | undefined;
            };
            services: {
                name: string;
                entity: ({
                    options: {
                        text: string;
                        link: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "helpLink";
                    field: string;
                    label?: string | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: false | undefined;
                } | {
                    type: "text";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "textarea";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    };
                    type: "singleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    };
                    type: "multipleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "checkbox";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxGroup";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxTree";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "radio";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "file";
                    label: string;
                    field: string;
                    options?: {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        auth_type: ("oauth" | "basic")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    };
                    type: "oauth";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                } | {
                    options: {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "custom";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                })[];
                title: string;
                options?: {
                    saveValidator?: string | undefined;
                } | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                groups?: {
                    label: string;
                    fields: string[];
                    options?: {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    } | undefined;
                }[] | undefined;
                style?: "page" | "dialog" | undefined;
                hook?: Record<string, any> | undefined;
                conf?: string | undefined;
                restHandlerName?: string | undefined;
                restHandlerModule?: string | undefined;
                restHandlerClass?: string | undefined;
                warning?: {
                    clone?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    create?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    edit?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    config?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                } | undefined;
                subTitle?: string | undefined;
                inputHelperModule?: string | undefined;
                disableNewInput?: boolean | undefined;
            }[];
            description?: string | undefined;
            useInputToggleConfirmation?: boolean | undefined;
            subDescription?: {
                text: string;
                links?: {
                    linkText: string;
                    link: string;
                    slug: string;
                }[] | undefined;
            } | undefined;
            menu?: {
                type: "external";
                src: string;
            } | undefined;
            groupsMenu?: {
                groupName: string;
                groupTitle: string;
                groupServices?: string[] | undefined;
            }[] | undefined;
            hideFieldId?: string | undefined;
            readonlyFieldId?: string | undefined;
        } | undefined;
        dashboard?: {
            panels: {
                name: string;
            }[];
            troubleshooting_url?: string | undefined;
            settings?: {
                custom_tab_name?: string | undefined;
            } | undefined;
        } | undefined;
    }>;
    alerts: z.ZodOptional<z.ZodArray<z.ZodObject<{
        name: z.ZodString;
        label: z.ZodString;
        description: z.ZodString;
        adaptiveResponse: z.ZodOptional<z.ZodObject<{
            task: z.ZodArray<z.ZodString, "many">;
            supportsAdhoc: z.ZodBoolean;
            supportsCloud: z.ZodBoolean;
            subject: z.ZodArray<z.ZodString, "many">;
            category: z.ZodArray<z.ZodString, "many">;
            technology: z.ZodArray<z.ZodObject<{
                version: z.ZodArray<z.ZodString, "many">;
                product: z.ZodString;
                vendor: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                version: string[];
                product: string;
                vendor: string;
            }, {
                version: string[];
                product: string;
                vendor: string;
            }>, "many">;
            drilldownUri: z.ZodOptional<z.ZodString>;
            sourcetype: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            task: string[];
            supportsAdhoc: boolean;
            supportsCloud: boolean;
            subject: string[];
            category: string[];
            technology: {
                version: string[];
                product: string;
                vendor: string;
            }[];
            drilldownUri?: string | undefined;
            sourcetype?: string | undefined;
        }, {
            task: string[];
            supportsAdhoc: boolean;
            supportsCloud: boolean;
            subject: string[];
            category: string[];
            technology: {
                version: string[];
                product: string;
                vendor: string;
            }[];
            drilldownUri?: string | undefined;
            sourcetype?: string | undefined;
        }>>;
        entity: z.ZodOptional<z.ZodArray<z.ZodDiscriminatedUnion<"type", [z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
            type: z.ZodString;
            field: z.ZodString;
            label: z.ZodString;
            help: z.ZodOptional<z.ZodString>;
            tooltip: z.ZodOptional<z.ZodString>;
        }, {
            required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
        }>, {
            type: z.ZodLiteral<"text">;
            validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"number">;
                range: z.ZodArray<z.ZodNumber, "many">;
                isInteger: z.ZodOptional<z.ZodBoolean>;
            }, "strip", z.ZodTypeAny, {
                type: "number";
                range: number[];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            }, {
                type: "number";
                range: number[];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            }>, z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"string">;
                minLength: z.ZodNumber;
                maxLength: z.ZodNumber;
            }, "strip", z.ZodTypeAny, {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            }, {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            }>, z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"regex">;
                pattern: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            }, {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            }>, z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"email">;
            }, "strip", z.ZodTypeAny, {
                type: "email";
                errorMsg?: string | undefined;
            }, {
                type: "email";
                errorMsg?: string | undefined;
            }>, z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"ipv4">;
            }, "strip", z.ZodTypeAny, {
                type: "ipv4";
                errorMsg?: string | undefined;
            }, {
                type: "ipv4";
                errorMsg?: string | undefined;
            }>, z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"url">;
            }, "strip", z.ZodTypeAny, {
                type: "url";
                errorMsg?: string | undefined;
            }, {
                type: "url";
                errorMsg?: string | undefined;
            }>, z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"date">;
            }, "strip", z.ZodTypeAny, {
                type: "date";
                errorMsg?: string | undefined;
            }, {
                type: "date";
                errorMsg?: string | undefined;
            }>]>, "many">>;
            defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
            options: z.ZodOptional<z.ZodObject<{
                display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
            }, "strip", z.ZodTypeAny, {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            }, {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            }>>;
            modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                fieldsToModify: z.ZodArray<z.ZodObject<{
                    fieldId: z.ZodString;
                    display: z.ZodOptional<z.ZodBoolean>;
                    value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                    disabled: z.ZodOptional<z.ZodBoolean>;
                    required: z.ZodOptional<z.ZodBoolean>;
                    help: z.ZodOptional<z.ZodString>;
                    label: z.ZodOptional<z.ZodString>;
                    markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                        markdownType: z.ZodLiteral<"text">;
                        text: z.ZodString;
                        color: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    }, {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    }>, z.ZodObject<{
                        markdownType: z.ZodLiteral<"hybrid">;
                        text: z.ZodString;
                        token: z.ZodString;
                        linkText: z.ZodString;
                        link: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    }, {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    }>, z.ZodObject<{
                        markdownType: z.ZodLiteral<"link">;
                        text: z.ZodString;
                        link: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        markdownType: "link";
                        text: string;
                        link: string;
                    }, {
                        markdownType: "link";
                        text: string;
                        link: string;
                    }>, z.ZodObject<{
                        markdownType: z.ZodOptional<z.ZodUndefined>;
                        text: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        text: string;
                        markdownType?: undefined;
                    }, {
                        text: string;
                        markdownType?: undefined;
                    }>]>>;
                }, "strip", z.ZodTypeAny, {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }, {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }>, "many">;
            }, "strip", z.ZodTypeAny, {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }, {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }>, "many">>;
        }>, "strip", z.ZodTypeAny, {
            type: "text";
            label: string;
            field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            } | undefined;
            help?: string | undefined;
            tooltip?: string | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: number[];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        }, {
            type: "text";
            label: string;
            field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            } | undefined;
            help?: string | undefined;
            tooltip?: string | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: number[];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        }>, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
            type: z.ZodString;
            field: z.ZodString;
            label: z.ZodString;
            help: z.ZodOptional<z.ZodString>;
            tooltip: z.ZodOptional<z.ZodString>;
        }, {
            required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
        }>, {
            type: z.ZodLiteral<"textarea">;
            validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"number">;
                range: z.ZodArray<z.ZodNumber, "many">;
                isInteger: z.ZodOptional<z.ZodBoolean>;
            }, "strip", z.ZodTypeAny, {
                type: "number";
                range: number[];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            }, {
                type: "number";
                range: number[];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            }>, z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"string">;
                minLength: z.ZodNumber;
                maxLength: z.ZodNumber;
            }, "strip", z.ZodTypeAny, {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            }, {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            }>, z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"regex">;
                pattern: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            }, {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            }>, z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"email">;
            }, "strip", z.ZodTypeAny, {
                type: "email";
                errorMsg?: string | undefined;
            }, {
                type: "email";
                errorMsg?: string | undefined;
            }>, z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"ipv4">;
            }, "strip", z.ZodTypeAny, {
                type: "ipv4";
                errorMsg?: string | undefined;
            }, {
                type: "ipv4";
                errorMsg?: string | undefined;
            }>, z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"url">;
            }, "strip", z.ZodTypeAny, {
                type: "url";
                errorMsg?: string | undefined;
            }, {
                type: "url";
                errorMsg?: string | undefined;
            }>, z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"date">;
            }, "strip", z.ZodTypeAny, {
                type: "date";
                errorMsg?: string | undefined;
            }, {
                type: "date";
                errorMsg?: string | undefined;
            }>]>, "many">>;
            defaultValue: z.ZodOptional<z.ZodString>;
            options: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
                display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
            }, {
                rowsMin: z.ZodOptional<z.ZodNumber>;
                rowsMax: z.ZodOptional<z.ZodNumber>;
            }>, "strip", z.ZodTypeAny, {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                rowsMin?: number | undefined;
                rowsMax?: number | undefined;
            }, {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                rowsMin?: number | undefined;
                rowsMax?: number | undefined;
            }>>;
            modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                fieldsToModify: z.ZodArray<z.ZodObject<{
                    fieldId: z.ZodString;
                    display: z.ZodOptional<z.ZodBoolean>;
                    value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                    disabled: z.ZodOptional<z.ZodBoolean>;
                    required: z.ZodOptional<z.ZodBoolean>;
                    help: z.ZodOptional<z.ZodString>;
                    label: z.ZodOptional<z.ZodString>;
                    markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                        markdownType: z.ZodLiteral<"text">;
                        text: z.ZodString;
                        color: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    }, {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    }>, z.ZodObject<{
                        markdownType: z.ZodLiteral<"hybrid">;
                        text: z.ZodString;
                        token: z.ZodString;
                        linkText: z.ZodString;
                        link: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    }, {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    }>, z.ZodObject<{
                        markdownType: z.ZodLiteral<"link">;
                        text: z.ZodString;
                        link: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        markdownType: "link";
                        text: string;
                        link: string;
                    }, {
                        markdownType: "link";
                        text: string;
                        link: string;
                    }>, z.ZodObject<{
                        markdownType: z.ZodOptional<z.ZodUndefined>;
                        text: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        text: string;
                        markdownType?: undefined;
                    }, {
                        text: string;
                        markdownType?: undefined;
                    }>]>>;
                }, "strip", z.ZodTypeAny, {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }, {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }>, "many">;
            }, "strip", z.ZodTypeAny, {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }, {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }>, "many">>;
        }>, "strip", z.ZodTypeAny, {
            type: "textarea";
            label: string;
            field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                rowsMin?: number | undefined;
                rowsMax?: number | undefined;
            } | undefined;
            help?: string | undefined;
            tooltip?: string | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: number[];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        }, {
            type: "textarea";
            label: string;
            field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                rowsMin?: number | undefined;
                rowsMax?: number | undefined;
            } | undefined;
            help?: string | undefined;
            tooltip?: string | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: number[];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        }>, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
            type: z.ZodString;
            field: z.ZodString;
            label: z.ZodString;
            help: z.ZodOptional<z.ZodString>;
            tooltip: z.ZodOptional<z.ZodString>;
        }, {
            required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
        }>, {
            type: z.ZodLiteral<"singleSelect">;
            validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"number">;
                range: z.ZodArray<z.ZodNumber, "many">;
                isInteger: z.ZodOptional<z.ZodBoolean>;
            }, "strip", z.ZodTypeAny, {
                type: "number";
                range: number[];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            }, {
                type: "number";
                range: number[];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            }>, z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"string">;
                minLength: z.ZodNumber;
                maxLength: z.ZodNumber;
            }, "strip", z.ZodTypeAny, {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            }, {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            }>, z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"regex">;
                pattern: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            }, {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            }>, z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"email">;
            }, "strip", z.ZodTypeAny, {
                type: "email";
                errorMsg?: string | undefined;
            }, {
                type: "email";
                errorMsg?: string | undefined;
            }>, z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"ipv4">;
            }, "strip", z.ZodTypeAny, {
                type: "ipv4";
                errorMsg?: string | undefined;
            }, {
                type: "ipv4";
                errorMsg?: string | undefined;
            }>, z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"url">;
            }, "strip", z.ZodTypeAny, {
                type: "url";
                errorMsg?: string | undefined;
            }, {
                type: "url";
                errorMsg?: string | undefined;
            }>, z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"date">;
            }, "strip", z.ZodTypeAny, {
                type: "date";
                errorMsg?: string | undefined;
            }, {
                type: "date";
                errorMsg?: string | undefined;
            }>]>, "many">>;
            defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
            options: z.ZodObject<z.objectUtil.extendShape<{
                display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
            }, {
                disableSearch: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                createSearchChoice: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                referenceName: z.ZodOptional<z.ZodString>;
                endpointUrl: z.ZodOptional<z.ZodString>;
                allowList: z.ZodOptional<z.ZodString>;
                denyList: z.ZodOptional<z.ZodString>;
                labelField: z.ZodOptional<z.ZodString>;
                valueField: z.ZodOptional<z.ZodString>;
                autoCompleteFields: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                    value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                    label: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    value: string | number | boolean;
                    label: string;
                }, {
                    value: string | number | boolean;
                    label: string;
                }>, z.ZodObject<{
                    label: z.ZodString;
                    children: z.ZodArray<z.ZodObject<{
                        value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                        label: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        value: string | number | boolean;
                        label: string;
                    }, {
                        value: string | number | boolean;
                        label: string;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    label: string;
                    children: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                }, {
                    label: string;
                    children: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                }>]>, "many">>;
                dependencies: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                    label: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    value: string | number | boolean;
                    label: string;
                }, {
                    value: string | number | boolean;
                    label: string;
                }>, "many">>;
            }>, "strip", z.ZodTypeAny, {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                disableSearch?: boolean | undefined;
                createSearchChoice?: boolean | undefined;
                referenceName?: string | undefined;
                endpointUrl?: string | undefined;
                allowList?: string | undefined;
                denyList?: string | undefined;
                labelField?: string | undefined;
                valueField?: string | undefined;
                autoCompleteFields?: ({
                    value: string | number | boolean;
                    label: string;
                } | {
                    label: string;
                    children: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                })[] | undefined;
                dependencies?: string[] | undefined;
                items?: {
                    value: string | number | boolean;
                    label: string;
                }[] | undefined;
            }, {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                disableSearch?: boolean | undefined;
                createSearchChoice?: boolean | undefined;
                referenceName?: string | undefined;
                endpointUrl?: string | undefined;
                allowList?: string | undefined;
                denyList?: string | undefined;
                labelField?: string | undefined;
                valueField?: string | undefined;
                autoCompleteFields?: ({
                    value: string | number | boolean;
                    label: string;
                } | {
                    label: string;
                    children: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                })[] | undefined;
                dependencies?: string[] | undefined;
                items?: {
                    value: string | number | boolean;
                    label: string;
                }[] | undefined;
            }>;
            modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                fieldsToModify: z.ZodArray<z.ZodObject<{
                    fieldId: z.ZodString;
                    display: z.ZodOptional<z.ZodBoolean>;
                    value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                    disabled: z.ZodOptional<z.ZodBoolean>;
                    required: z.ZodOptional<z.ZodBoolean>;
                    help: z.ZodOptional<z.ZodString>;
                    label: z.ZodOptional<z.ZodString>;
                    markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                        markdownType: z.ZodLiteral<"text">;
                        text: z.ZodString;
                        color: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    }, {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    }>, z.ZodObject<{
                        markdownType: z.ZodLiteral<"hybrid">;
                        text: z.ZodString;
                        token: z.ZodString;
                        linkText: z.ZodString;
                        link: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    }, {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    }>, z.ZodObject<{
                        markdownType: z.ZodLiteral<"link">;
                        text: z.ZodString;
                        link: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        markdownType: "link";
                        text: string;
                        link: string;
                    }, {
                        markdownType: "link";
                        text: string;
                        link: string;
                    }>, z.ZodObject<{
                        markdownType: z.ZodOptional<z.ZodUndefined>;
                        text: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        text: string;
                        markdownType?: undefined;
                    }, {
                        text: string;
                        markdownType?: undefined;
                    }>]>>;
                }, "strip", z.ZodTypeAny, {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }, {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }>, "many">;
            }, "strip", z.ZodTypeAny, {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }, {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }>, "many">>;
        }>, "strip", z.ZodTypeAny, {
            options: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                disableSearch?: boolean | undefined;
                createSearchChoice?: boolean | undefined;
                referenceName?: string | undefined;
                endpointUrl?: string | undefined;
                allowList?: string | undefined;
                denyList?: string | undefined;
                labelField?: string | undefined;
                valueField?: string | undefined;
                autoCompleteFields?: ({
                    value: string | number | boolean;
                    label: string;
                } | {
                    label: string;
                    children: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                })[] | undefined;
                dependencies?: string[] | undefined;
                items?: {
                    value: string | number | boolean;
                    label: string;
                }[] | undefined;
            };
            type: "singleSelect";
            label: string;
            field: string;
            help?: string | undefined;
            tooltip?: string | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: number[];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        }, {
            options: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                disableSearch?: boolean | undefined;
                createSearchChoice?: boolean | undefined;
                referenceName?: string | undefined;
                endpointUrl?: string | undefined;
                allowList?: string | undefined;
                denyList?: string | undefined;
                labelField?: string | undefined;
                valueField?: string | undefined;
                autoCompleteFields?: ({
                    value: string | number | boolean;
                    label: string;
                } | {
                    label: string;
                    children: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                })[] | undefined;
                dependencies?: string[] | undefined;
                items?: {
                    value: string | number | boolean;
                    label: string;
                }[] | undefined;
            };
            type: "singleSelect";
            label: string;
            field: string;
            help?: string | undefined;
            tooltip?: string | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: number[];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        }>, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
            type: z.ZodString;
            field: z.ZodString;
            label: z.ZodString;
            help: z.ZodOptional<z.ZodString>;
            tooltip: z.ZodOptional<z.ZodString>;
        }, {
            required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
        }>, {
            type: z.ZodLiteral<"checkbox">;
            defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodBoolean]>>;
            options: z.ZodOptional<z.ZodObject<{
                display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
            }, "strip", z.ZodTypeAny, {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            }, {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            }>>;
            modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                fieldsToModify: z.ZodArray<z.ZodObject<{
                    fieldId: z.ZodString;
                    display: z.ZodOptional<z.ZodBoolean>;
                    value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                    disabled: z.ZodOptional<z.ZodBoolean>;
                    required: z.ZodOptional<z.ZodBoolean>;
                    help: z.ZodOptional<z.ZodString>;
                    label: z.ZodOptional<z.ZodString>;
                    markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                        markdownType: z.ZodLiteral<"text">;
                        text: z.ZodString;
                        color: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    }, {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    }>, z.ZodObject<{
                        markdownType: z.ZodLiteral<"hybrid">;
                        text: z.ZodString;
                        token: z.ZodString;
                        linkText: z.ZodString;
                        link: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    }, {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    }>, z.ZodObject<{
                        markdownType: z.ZodLiteral<"link">;
                        text: z.ZodString;
                        link: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        markdownType: "link";
                        text: string;
                        link: string;
                    }, {
                        markdownType: "link";
                        text: string;
                        link: string;
                    }>, z.ZodObject<{
                        markdownType: z.ZodOptional<z.ZodUndefined>;
                        text: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        text: string;
                        markdownType?: undefined;
                    }, {
                        text: string;
                        markdownType?: undefined;
                    }>]>>;
                }, "strip", z.ZodTypeAny, {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }, {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }>, "many">;
            }, "strip", z.ZodTypeAny, {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }, {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }>, "many">>;
        }>, "strip", z.ZodTypeAny, {
            type: "checkbox";
            label: string;
            field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            } | undefined;
            help?: string | undefined;
            tooltip?: string | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            defaultValue?: number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        }, {
            type: "checkbox";
            label: string;
            field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            } | undefined;
            help?: string | undefined;
            tooltip?: string | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            defaultValue?: number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        }>, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
            type: z.ZodString;
            field: z.ZodString;
            label: z.ZodString;
            help: z.ZodOptional<z.ZodString>;
            tooltip: z.ZodOptional<z.ZodString>;
        }, {
            required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
        }>, {
            type: z.ZodLiteral<"radio">;
            defaultValue: z.ZodOptional<z.ZodString>;
            options: z.ZodObject<z.objectUtil.extendShape<{
                display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
            }, {
                items: z.ZodArray<z.ZodObject<{
                    value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                    label: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    value: string | number | boolean;
                    label: string;
                }, {
                    value: string | number | boolean;
                    label: string;
                }>, "many">;
            }>, "strip", z.ZodTypeAny, {
                items: {
                    value: string | number | boolean;
                    label: string;
                }[];
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            }, {
                items: {
                    value: string | number | boolean;
                    label: string;
                }[];
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            }>;
            modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                fieldsToModify: z.ZodArray<z.ZodObject<{
                    fieldId: z.ZodString;
                    display: z.ZodOptional<z.ZodBoolean>;
                    value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                    disabled: z.ZodOptional<z.ZodBoolean>;
                    required: z.ZodOptional<z.ZodBoolean>;
                    help: z.ZodOptional<z.ZodString>;
                    label: z.ZodOptional<z.ZodString>;
                    markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                        markdownType: z.ZodLiteral<"text">;
                        text: z.ZodString;
                        color: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    }, {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    }>, z.ZodObject<{
                        markdownType: z.ZodLiteral<"hybrid">;
                        text: z.ZodString;
                        token: z.ZodString;
                        linkText: z.ZodString;
                        link: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    }, {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    }>, z.ZodObject<{
                        markdownType: z.ZodLiteral<"link">;
                        text: z.ZodString;
                        link: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        markdownType: "link";
                        text: string;
                        link: string;
                    }, {
                        markdownType: "link";
                        text: string;
                        link: string;
                    }>, z.ZodObject<{
                        markdownType: z.ZodOptional<z.ZodUndefined>;
                        text: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        text: string;
                        markdownType?: undefined;
                    }, {
                        text: string;
                        markdownType?: undefined;
                    }>]>>;
                }, "strip", z.ZodTypeAny, {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }, {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }>, "many">;
            }, "strip", z.ZodTypeAny, {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }, {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }>, "many">>;
        }>, "strip", z.ZodTypeAny, {
            options: {
                items: {
                    value: string | number | boolean;
                    label: string;
                }[];
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            };
            type: "radio";
            label: string;
            field: string;
            help?: string | undefined;
            tooltip?: string | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            defaultValue?: string | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        }, {
            options: {
                items: {
                    value: string | number | boolean;
                    label: string;
                }[];
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            };
            type: "radio";
            label: string;
            field: string;
            help?: string | undefined;
            tooltip?: string | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            defaultValue?: string | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        }>, z.ZodObject<z.objectUtil.extendShape<{
            type: z.ZodString;
            field: z.ZodString;
            label: z.ZodString;
            help: z.ZodOptional<z.ZodString>;
            tooltip: z.ZodOptional<z.ZodString>;
        }, {
            type: z.ZodLiteral<"singleSelectSplunkSearch">;
            defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
            search: z.ZodOptional<z.ZodString>;
            valueField: z.ZodOptional<z.ZodString>;
            labelField: z.ZodOptional<z.ZodString>;
            options: z.ZodOptional<z.ZodObject<{
                items: z.ZodArray<z.ZodObject<{
                    value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                    label: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    value: string | number | boolean;
                    label: string;
                }, {
                    value: string | number | boolean;
                    label: string;
                }>, "many">;
            }, "strip", z.ZodTypeAny, {
                items: {
                    value: string | number | boolean;
                    label: string;
                }[];
            }, {
                items: {
                    value: string | number | boolean;
                    label: string;
                }[];
            }>>;
        }>, "strip", z.ZodTypeAny, {
            type: "singleSelectSplunkSearch";
            label: string;
            field: string;
            options?: {
                items: {
                    value: string | number | boolean;
                    label: string;
                }[];
            } | undefined;
            help?: string | undefined;
            tooltip?: string | undefined;
            defaultValue?: string | number | boolean | undefined;
            labelField?: string | undefined;
            valueField?: string | undefined;
            search?: string | undefined;
        }, {
            type: "singleSelectSplunkSearch";
            label: string;
            field: string;
            options?: {
                items: {
                    value: string | number | boolean;
                    label: string;
                }[];
            } | undefined;
            help?: string | undefined;
            tooltip?: string | undefined;
            defaultValue?: string | number | boolean | undefined;
            labelField?: string | undefined;
            valueField?: string | undefined;
            search?: string | undefined;
        }>]>, "many">>;
    }, "strip", z.ZodTypeAny, {
        name: string;
        label: string;
        description: string;
        entity?: ({
            type: "text";
            label: string;
            field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            } | undefined;
            help?: string | undefined;
            tooltip?: string | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: number[];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        } | {
            type: "textarea";
            label: string;
            field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                rowsMin?: number | undefined;
                rowsMax?: number | undefined;
            } | undefined;
            help?: string | undefined;
            tooltip?: string | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: number[];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        } | {
            options: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                disableSearch?: boolean | undefined;
                createSearchChoice?: boolean | undefined;
                referenceName?: string | undefined;
                endpointUrl?: string | undefined;
                allowList?: string | undefined;
                denyList?: string | undefined;
                labelField?: string | undefined;
                valueField?: string | undefined;
                autoCompleteFields?: ({
                    value: string | number | boolean;
                    label: string;
                } | {
                    label: string;
                    children: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                })[] | undefined;
                dependencies?: string[] | undefined;
                items?: {
                    value: string | number | boolean;
                    label: string;
                }[] | undefined;
            };
            type: "singleSelect";
            label: string;
            field: string;
            help?: string | undefined;
            tooltip?: string | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: number[];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        } | {
            type: "checkbox";
            label: string;
            field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            } | undefined;
            help?: string | undefined;
            tooltip?: string | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            defaultValue?: number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        } | {
            options: {
                items: {
                    value: string | number | boolean;
                    label: string;
                }[];
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            };
            type: "radio";
            label: string;
            field: string;
            help?: string | undefined;
            tooltip?: string | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            defaultValue?: string | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        } | {
            type: "singleSelectSplunkSearch";
            label: string;
            field: string;
            options?: {
                items: {
                    value: string | number | boolean;
                    label: string;
                }[];
            } | undefined;
            help?: string | undefined;
            tooltip?: string | undefined;
            defaultValue?: string | number | boolean | undefined;
            labelField?: string | undefined;
            valueField?: string | undefined;
            search?: string | undefined;
        })[] | undefined;
        adaptiveResponse?: {
            task: string[];
            supportsAdhoc: boolean;
            supportsCloud: boolean;
            subject: string[];
            category: string[];
            technology: {
                version: string[];
                product: string;
                vendor: string;
            }[];
            drilldownUri?: string | undefined;
            sourcetype?: string | undefined;
        } | undefined;
    }, {
        name: string;
        label: string;
        description: string;
        entity?: ({
            type: "text";
            label: string;
            field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            } | undefined;
            help?: string | undefined;
            tooltip?: string | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: number[];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        } | {
            type: "textarea";
            label: string;
            field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                rowsMin?: number | undefined;
                rowsMax?: number | undefined;
            } | undefined;
            help?: string | undefined;
            tooltip?: string | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: number[];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        } | {
            options: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                disableSearch?: boolean | undefined;
                createSearchChoice?: boolean | undefined;
                referenceName?: string | undefined;
                endpointUrl?: string | undefined;
                allowList?: string | undefined;
                denyList?: string | undefined;
                labelField?: string | undefined;
                valueField?: string | undefined;
                autoCompleteFields?: ({
                    value: string | number | boolean;
                    label: string;
                } | {
                    label: string;
                    children: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                })[] | undefined;
                dependencies?: string[] | undefined;
                items?: {
                    value: string | number | boolean;
                    label: string;
                }[] | undefined;
            };
            type: "singleSelect";
            label: string;
            field: string;
            help?: string | undefined;
            tooltip?: string | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: number[];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        } | {
            type: "checkbox";
            label: string;
            field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            } | undefined;
            help?: string | undefined;
            tooltip?: string | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            defaultValue?: number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        } | {
            options: {
                items: {
                    value: string | number | boolean;
                    label: string;
                }[];
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            };
            type: "radio";
            label: string;
            field: string;
            help?: string | undefined;
            tooltip?: string | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            defaultValue?: string | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        } | {
            type: "singleSelectSplunkSearch";
            label: string;
            field: string;
            options?: {
                items: {
                    value: string | number | boolean;
                    label: string;
                }[];
            } | undefined;
            help?: string | undefined;
            tooltip?: string | undefined;
            defaultValue?: string | number | boolean | undefined;
            labelField?: string | undefined;
            valueField?: string | undefined;
            search?: string | undefined;
        })[] | undefined;
        adaptiveResponse?: {
            task: string[];
            supportsAdhoc: boolean;
            supportsCloud: boolean;
            subject: string[];
            category: string[];
            technology: {
                version: string[];
                product: string;
                vendor: string;
            }[];
            drilldownUri?: string | undefined;
            sourcetype?: string | undefined;
        } | undefined;
    }>, "many">>;
}, "strip", z.ZodTypeAny, {
    meta: {
        displayName: string;
        name: string;
        restRoot: string;
        version: string;
        apiVersion?: string | undefined;
        schemaVersion?: string | undefined;
        _uccVersion?: string | undefined;
        hideUCCVersion?: boolean | undefined;
        checkForUpdates?: boolean | undefined;
        searchViewDefault?: boolean | undefined;
        isVisible?: boolean | undefined;
        supportedThemes?: string[] | undefined;
    };
    pages: {
        configuration: {
            title: string;
            tabs: {
                name: string;
                title: string;
                options?: {
                    saveValidator?: string | undefined;
                } | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                groups?: {
                    label: string;
                    fields: string[];
                    options?: {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    } | undefined;
                }[] | undefined;
                entity?: ({
                    options: {
                        text: string;
                        link: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "helpLink";
                    field: string;
                    label?: string | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: false | undefined;
                } | {
                    type: "text";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "textarea";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    };
                    type: "singleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    };
                    type: "multipleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "checkbox";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxGroup";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxTree";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "radio";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "file";
                    label: string;
                    field: string;
                    options?: {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        auth_type: ("oauth" | "basic")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    };
                    type: "oauth";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                } | {
                    options: {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "custom";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                })[] | undefined;
                table?: {
                    header: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                        customCell?: Record<string, any> | undefined;
                    }[];
                    actions: ("clone" | "delete" | "edit")[];
                    moreInfo?: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                    }[] | undefined;
                    customRow?: Record<string, any> | undefined;
                } | undefined;
                style?: "page" | "dialog" | undefined;
                hook?: Record<string, any> | undefined;
                conf?: string | undefined;
                restHandlerName?: string | undefined;
                restHandlerModule?: string | undefined;
                restHandlerClass?: string | undefined;
                customTab?: Record<string, any> | undefined;
                warning?: {
                    clone?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    create?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    edit?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    config?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                } | undefined;
            }[];
            description?: string | undefined;
            subDescription?: {
                text: string;
                links?: {
                    linkText: string;
                    link: string;
                    slug: string;
                }[] | undefined;
            } | undefined;
        };
        inputs?: {
            title: string;
            services: {
                name: string;
                entity: ({
                    options: {
                        text: string;
                        link: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "helpLink";
                    field: string;
                    label?: string | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: false | undefined;
                } | {
                    type: "text";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "textarea";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    };
                    type: "singleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    };
                    type: "multipleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "checkbox";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxGroup";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxTree";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "radio";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "file";
                    label: string;
                    field: string;
                    options?: {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        auth_type: ("oauth" | "basic")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    };
                    type: "oauth";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                } | {
                    options: {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "custom";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                })[];
                title: string;
                table: {
                    header: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                        customCell?: Record<string, any> | undefined;
                    }[];
                    actions: ("clone" | "delete" | "edit" | "search")[];
                    moreInfo?: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                    }[] | undefined;
                    customRow?: Record<string, any> | undefined;
                };
                options?: {
                    saveValidator?: string | undefined;
                } | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                groups?: {
                    label: string;
                    fields: string[];
                    options?: {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    } | undefined;
                }[] | undefined;
                style?: "page" | "dialog" | undefined;
                hook?: Record<string, any> | undefined;
                conf?: string | undefined;
                restHandlerName?: string | undefined;
                restHandlerModule?: string | undefined;
                restHandlerClass?: string | undefined;
                warning?: {
                    clone?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    create?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    edit?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    config?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                } | undefined;
                subTitle?: string | undefined;
                inputHelperModule?: string | undefined;
                disableNewInput?: boolean | undefined;
                description?: string | undefined;
                useInputToggleConfirmation?: boolean | undefined;
            }[];
        } | {
            title: string;
            table: {
                header: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                    customCell?: Record<string, any> | undefined;
                }[];
                actions: ("clone" | "delete" | "edit" | "search")[];
                moreInfo?: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                }[] | undefined;
                customRow?: Record<string, any> | undefined;
            };
            services: {
                name: string;
                entity: ({
                    options: {
                        text: string;
                        link: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "helpLink";
                    field: string;
                    label?: string | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: false | undefined;
                } | {
                    type: "text";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "textarea";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    };
                    type: "singleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    };
                    type: "multipleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "checkbox";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxGroup";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxTree";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "radio";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "file";
                    label: string;
                    field: string;
                    options?: {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        auth_type: ("oauth" | "basic")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    };
                    type: "oauth";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                } | {
                    options: {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "custom";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                })[];
                title: string;
                options?: {
                    saveValidator?: string | undefined;
                } | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                groups?: {
                    label: string;
                    fields: string[];
                    options?: {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    } | undefined;
                }[] | undefined;
                style?: "page" | "dialog" | undefined;
                hook?: Record<string, any> | undefined;
                conf?: string | undefined;
                restHandlerName?: string | undefined;
                restHandlerModule?: string | undefined;
                restHandlerClass?: string | undefined;
                warning?: {
                    clone?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    create?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    edit?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    config?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                } | undefined;
                subTitle?: string | undefined;
                inputHelperModule?: string | undefined;
                disableNewInput?: boolean | undefined;
            }[];
            description?: string | undefined;
            useInputToggleConfirmation?: boolean | undefined;
            subDescription?: {
                text: string;
                links?: {
                    linkText: string;
                    link: string;
                    slug: string;
                }[] | undefined;
            } | undefined;
            menu?: {
                type: "external";
                src: string;
            } | undefined;
            groupsMenu?: {
                groupName: string;
                groupTitle: string;
                groupServices?: string[] | undefined;
            }[] | undefined;
            hideFieldId?: string | undefined;
            readonlyFieldId?: string | undefined;
        } | undefined;
        dashboard?: {
            panels: {
                name: string;
            }[];
            troubleshooting_url?: string | undefined;
            settings?: {
                custom_tab_name?: string | undefined;
            } | undefined;
        } | undefined;
    };
    alerts?: {
        name: string;
        label: string;
        description: string;
        entity?: ({
            type: "text";
            label: string;
            field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            } | undefined;
            help?: string | undefined;
            tooltip?: string | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: number[];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        } | {
            type: "textarea";
            label: string;
            field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                rowsMin?: number | undefined;
                rowsMax?: number | undefined;
            } | undefined;
            help?: string | undefined;
            tooltip?: string | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: number[];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        } | {
            options: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                disableSearch?: boolean | undefined;
                createSearchChoice?: boolean | undefined;
                referenceName?: string | undefined;
                endpointUrl?: string | undefined;
                allowList?: string | undefined;
                denyList?: string | undefined;
                labelField?: string | undefined;
                valueField?: string | undefined;
                autoCompleteFields?: ({
                    value: string | number | boolean;
                    label: string;
                } | {
                    label: string;
                    children: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                })[] | undefined;
                dependencies?: string[] | undefined;
                items?: {
                    value: string | number | boolean;
                    label: string;
                }[] | undefined;
            };
            type: "singleSelect";
            label: string;
            field: string;
            help?: string | undefined;
            tooltip?: string | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: number[];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        } | {
            type: "checkbox";
            label: string;
            field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            } | undefined;
            help?: string | undefined;
            tooltip?: string | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            defaultValue?: number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        } | {
            options: {
                items: {
                    value: string | number | boolean;
                    label: string;
                }[];
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            };
            type: "radio";
            label: string;
            field: string;
            help?: string | undefined;
            tooltip?: string | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            defaultValue?: string | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        } | {
            type: "singleSelectSplunkSearch";
            label: string;
            field: string;
            options?: {
                items: {
                    value: string | number | boolean;
                    label: string;
                }[];
            } | undefined;
            help?: string | undefined;
            tooltip?: string | undefined;
            defaultValue?: string | number | boolean | undefined;
            labelField?: string | undefined;
            valueField?: string | undefined;
            search?: string | undefined;
        })[] | undefined;
        adaptiveResponse?: {
            task: string[];
            supportsAdhoc: boolean;
            supportsCloud: boolean;
            subject: string[];
            category: string[];
            technology: {
                version: string[];
                product: string;
                vendor: string;
            }[];
            drilldownUri?: string | undefined;
            sourcetype?: string | undefined;
        } | undefined;
    }[] | undefined;
}, {
    meta: {
        displayName: string;
        name: string;
        restRoot: string;
        version: string;
        apiVersion?: string | undefined;
        schemaVersion?: string | undefined;
        _uccVersion?: string | undefined;
        hideUCCVersion?: boolean | undefined;
        checkForUpdates?: boolean | undefined;
        searchViewDefault?: boolean | undefined;
        isVisible?: boolean | undefined;
        supportedThemes?: string[] | undefined;
    };
    pages: {
        configuration: {
            title: string;
            tabs: {
                name: string;
                title: string;
                options?: {
                    saveValidator?: string | undefined;
                } | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                groups?: {
                    label: string;
                    fields: string[];
                    options?: {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    } | undefined;
                }[] | undefined;
                entity?: ({
                    options: {
                        text: string;
                        link: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "helpLink";
                    field: string;
                    label?: string | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: false | undefined;
                } | {
                    type: "text";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "textarea";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    };
                    type: "singleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    };
                    type: "multipleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "checkbox";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxGroup";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxTree";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "radio";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "file";
                    label: string;
                    field: string;
                    options?: {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        auth_type: ("oauth" | "basic")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    };
                    type: "oauth";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                } | {
                    options: {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "custom";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                })[] | undefined;
                table?: {
                    header: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                        customCell?: Record<string, any> | undefined;
                    }[];
                    actions: ("clone" | "delete" | "edit")[];
                    moreInfo?: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                    }[] | undefined;
                    customRow?: Record<string, any> | undefined;
                } | undefined;
                style?: "page" | "dialog" | undefined;
                hook?: Record<string, any> | undefined;
                conf?: string | undefined;
                restHandlerName?: string | undefined;
                restHandlerModule?: string | undefined;
                restHandlerClass?: string | undefined;
                customTab?: Record<string, any> | undefined;
                warning?: {
                    clone?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    create?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    edit?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    config?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                } | undefined;
            }[];
            description?: string | undefined;
            subDescription?: {
                text: string;
                links?: {
                    linkText: string;
                    link: string;
                    slug: string;
                }[] | undefined;
            } | undefined;
        };
        inputs?: {
            title: string;
            services: {
                name: string;
                entity: ({
                    options: {
                        text: string;
                        link: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "helpLink";
                    field: string;
                    label?: string | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: false | undefined;
                } | {
                    type: "text";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "textarea";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    };
                    type: "singleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    };
                    type: "multipleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "checkbox";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxGroup";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxTree";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "radio";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "file";
                    label: string;
                    field: string;
                    options?: {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        auth_type: ("oauth" | "basic")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    };
                    type: "oauth";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                } | {
                    options: {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "custom";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                })[];
                title: string;
                table: {
                    header: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                        customCell?: Record<string, any> | undefined;
                    }[];
                    actions: ("clone" | "delete" | "edit" | "search")[];
                    moreInfo?: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                    }[] | undefined;
                    customRow?: Record<string, any> | undefined;
                };
                options?: {
                    saveValidator?: string | undefined;
                } | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                groups?: {
                    label: string;
                    fields: string[];
                    options?: {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    } | undefined;
                }[] | undefined;
                style?: "page" | "dialog" | undefined;
                hook?: Record<string, any> | undefined;
                conf?: string | undefined;
                restHandlerName?: string | undefined;
                restHandlerModule?: string | undefined;
                restHandlerClass?: string | undefined;
                warning?: {
                    clone?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    create?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    edit?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    config?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                } | undefined;
                subTitle?: string | undefined;
                inputHelperModule?: string | undefined;
                disableNewInput?: boolean | undefined;
                description?: string | undefined;
                useInputToggleConfirmation?: boolean | undefined;
            }[];
        } | {
            title: string;
            table: {
                header: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                    customCell?: Record<string, any> | undefined;
                }[];
                actions: ("clone" | "delete" | "edit" | "search")[];
                moreInfo?: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                }[] | undefined;
                customRow?: Record<string, any> | undefined;
            };
            services: {
                name: string;
                entity: ({
                    options: {
                        text: string;
                        link: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "helpLink";
                    field: string;
                    label?: string | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: false | undefined;
                } | {
                    type: "text";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "textarea";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    };
                    type: "singleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    };
                    type: "multipleSelect";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: number[];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "checkbox";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: number[];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxGroup";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxTree";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "radio";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "file";
                    label: string;
                    field: string;
                    options?: {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    } | undefined;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                markdownType: "text";
                                text: string;
                                color?: string | undefined;
                            } | {
                                markdownType: "hybrid";
                                text: string;
                                token: string;
                                linkText: string;
                                link: string;
                            } | {
                                markdownType: "link";
                                text: string;
                                link: string;
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        auth_type: ("oauth" | "basic")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            help: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: number[];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        markdownType: "text";
                                        text: string;
                                        color?: string | undefined;
                                    } | {
                                        markdownType: "hybrid";
                                        text: string;
                                        token: string;
                                        linkText: string;
                                        link: string;
                                    } | {
                                        markdownType: "link";
                                        text: string;
                                        link: string;
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    };
                    type: "oauth";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                } | {
                    options: {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "custom";
                    label: string;
                    field: string;
                    help?: string | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                })[];
                title: string;
                options?: {
                    saveValidator?: string | undefined;
                } | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                groups?: {
                    label: string;
                    fields: string[];
                    options?: {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    } | undefined;
                }[] | undefined;
                style?: "page" | "dialog" | undefined;
                hook?: Record<string, any> | undefined;
                conf?: string | undefined;
                restHandlerName?: string | undefined;
                restHandlerModule?: string | undefined;
                restHandlerClass?: string | undefined;
                warning?: {
                    clone?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    create?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    edit?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    config?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                } | undefined;
                subTitle?: string | undefined;
                inputHelperModule?: string | undefined;
                disableNewInput?: boolean | undefined;
            }[];
            description?: string | undefined;
            useInputToggleConfirmation?: boolean | undefined;
            subDescription?: {
                text: string;
                links?: {
                    linkText: string;
                    link: string;
                    slug: string;
                }[] | undefined;
            } | undefined;
            menu?: {
                type: "external";
                src: string;
            } | undefined;
            groupsMenu?: {
                groupName: string;
                groupTitle: string;
                groupServices?: string[] | undefined;
            }[] | undefined;
            hideFieldId?: string | undefined;
            readonlyFieldId?: string | undefined;
        } | undefined;
        dashboard?: {
            panels: {
                name: string;
            }[];
            troubleshooting_url?: string | undefined;
            settings?: {
                custom_tab_name?: string | undefined;
            } | undefined;
        } | undefined;
    };
    alerts?: {
        name: string;
        label: string;
        description: string;
        entity?: ({
            type: "text";
            label: string;
            field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            } | undefined;
            help?: string | undefined;
            tooltip?: string | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: number[];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        } | {
            type: "textarea";
            label: string;
            field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                rowsMin?: number | undefined;
                rowsMax?: number | undefined;
            } | undefined;
            help?: string | undefined;
            tooltip?: string | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: number[];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        } | {
            options: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                disableSearch?: boolean | undefined;
                createSearchChoice?: boolean | undefined;
                referenceName?: string | undefined;
                endpointUrl?: string | undefined;
                allowList?: string | undefined;
                denyList?: string | undefined;
                labelField?: string | undefined;
                valueField?: string | undefined;
                autoCompleteFields?: ({
                    value: string | number | boolean;
                    label: string;
                } | {
                    label: string;
                    children: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                })[] | undefined;
                dependencies?: string[] | undefined;
                items?: {
                    value: string | number | boolean;
                    label: string;
                }[] | undefined;
            };
            type: "singleSelect";
            label: string;
            field: string;
            help?: string | undefined;
            tooltip?: string | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: number[];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        } | {
            type: "checkbox";
            label: string;
            field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            } | undefined;
            help?: string | undefined;
            tooltip?: string | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            defaultValue?: number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        } | {
            options: {
                items: {
                    value: string | number | boolean;
                    label: string;
                }[];
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            };
            type: "radio";
            label: string;
            field: string;
            help?: string | undefined;
            tooltip?: string | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            defaultValue?: string | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        markdownType: "text";
                        text: string;
                        color?: string | undefined;
                    } | {
                        markdownType: "hybrid";
                        text: string;
                        token: string;
                        linkText: string;
                        link: string;
                    } | {
                        markdownType: "link";
                        text: string;
                        link: string;
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        } | {
            type: "singleSelectSplunkSearch";
            label: string;
            field: string;
            options?: {
                items: {
                    value: string | number | boolean;
                    label: string;
                }[];
            } | undefined;
            help?: string | undefined;
            tooltip?: string | undefined;
            defaultValue?: string | number | boolean | undefined;
            labelField?: string | undefined;
            valueField?: string | undefined;
            search?: string | undefined;
        })[] | undefined;
        adaptiveResponse?: {
            task: string[];
            supportsAdhoc: boolean;
            supportsCloud: boolean;
            subject: string[];
            category: string[];
            technology: {
                version: string[];
                product: string;
                vendor: string;
            }[];
            drilldownUri?: string | undefined;
            sourcetype?: string | undefined;
        } | undefined;
    }[] | undefined;
}>;
export type GlobalConfig = z.infer<typeof GlobalConfigSchema>;
